Class: Aws::BedrockRuntime::Types::ApplyGuardrailResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action taken in the response from the guardrail.

Returns:

  • (String)


80
81
82
83
84
85
86
87
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 80

class ApplyGuardrailResponse < Struct.new(
  :usage,
  :action,
  :outputs,
  :assessments)
  SENSITIVE = []
  include Aws::Structure
end

#assessmentsArray<Types::GuardrailAssessment>

The assessment details in the response from the guardrail.

Returns:



80
81
82
83
84
85
86
87
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 80

class ApplyGuardrailResponse < Struct.new(
  :usage,
  :action,
  :outputs,
  :assessments)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::GuardrailOutputContent>

The output details in the response from the guardrail.

Returns:



80
81
82
83
84
85
86
87
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 80

class ApplyGuardrailResponse < Struct.new(
  :usage,
  :action,
  :outputs,
  :assessments)
  SENSITIVE = []
  include Aws::Structure
end

#usageTypes::GuardrailUsage

The usage details in the response from the guardrail.



80
81
82
83
84
85
86
87
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 80

class ApplyGuardrailResponse < Struct.new(
  :usage,
  :action,
  :outputs,
  :assessments)
  SENSITIVE = []
  include Aws::Structure
end