Class: Aws::BedrockRuntime::Types::CachePointBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::CachePointBlock
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Defines a section of content to be cached for reuse in subsequent API calls.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ttl ⇒ String
Optional TTL duration for cache entries.
-
#type ⇒ String
Specifies the type of cache point within the CachePointBlock.
Instance Attribute Details
#ttl ⇒ String
Optional TTL duration for cache entries. When specified, enables extended TTL caching with the specified duration. When omitted, uses ‘type` value for caching behavior.
410 411 412 413 414 415 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 410 class CachePointBlock < Struct.new( :type, :ttl) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies the type of cache point within the CachePointBlock.
410 411 412 413 414 415 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 410 class CachePointBlock < Struct.new( :type, :ttl) SENSITIVE = [] include Aws::Structure end |