Class: Aws::BedrockRuntime::Types::ContentBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ContentBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
ContentBlock is a union - when making an API calls you must set exactly one of the members.
ContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ContentBlock corresponding to the set member.
A block of content for a message that you pass to, or receive from, a model with the Converse or ConverseStream API operations.
Defined Under Namespace
Classes: Audio, CachePoint, CitationsContent, Document, GuardContent, Image, ReasoningContent, SearchResult, Text, ToolAddition, ToolRemoval, ToolResult, ToolUse, Unknown, Video
Constant Summary collapse
- SENSITIVE =
[:reasoning_content]
Instance Attribute Summary collapse
-
#audio ⇒ Types::AudioBlock
An audio content block containing audio data in the conversation.
-
#cache_point ⇒ Types::CachePointBlock
CachePoint to include in the message.
-
#citations_content ⇒ Types::CitationsContentBlock
A content block that contains both generated text and associated citation information, providing traceability between the response and source documents.
-
#document ⇒ Types::DocumentBlock
A document to include in the message.
-
#guard_content ⇒ Types::GuardrailConverseContentBlock
Contains the content to assess with the guardrail.
-
#image ⇒ Types::ImageBlock
Image to include in the message.
-
#reasoning_content ⇒ Types::ReasoningContentBlock
Contains content regarding the reasoning that is carried out by the model.
-
#search_result ⇒ Types::SearchResultBlock
Search result to include in the message.
-
#text ⇒ String
Text to include in the message.
-
#tool_addition ⇒ Types::ToolAdditionBlock
A content block for adding a tool to the available tool set mid-conversation.
-
#tool_removal ⇒ Types::ToolRemovalBlock
A content block for removing a tool from the available tool set mid-conversation.
-
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
-
#tool_use ⇒ Types::ToolUseBlock
Information about a tool use request from a model.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#video ⇒ Types::VideoBlock
Video to include in the message.
Instance Attribute Details
#audio ⇒ Types::AudioBlock
An audio content block containing audio data in the conversation.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#cache_point ⇒ Types::CachePointBlock
CachePoint to include in the message.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#citations_content ⇒ Types::CitationsContentBlock
A content block that contains both generated text and associated citation information, providing traceability between the response and source documents.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#document ⇒ Types::DocumentBlock
A document to include in the message.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#guard_content ⇒ Types::GuardrailConverseContentBlock
Contains the content to assess with the guardrail. If you don't
specify guardContent in a call to the Converse API, the guardrail
(if passed in the Converse API) assesses the entire message.
For more information, see Use a guardrail with the Converse API in the Amazon Bedrock User Guide.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#image ⇒ Types::ImageBlock
Image to include in the message.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#reasoning_content ⇒ Types::ReasoningContentBlock
Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#search_result ⇒ Types::SearchResultBlock
Search result to include in the message.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#text ⇒ String
Text to include in the message.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_addition ⇒ Types::ToolAdditionBlock
A content block for adding a tool to the available tool set
mid-conversation. Each block references a single tool via its tool
field. Use within a system role message to make a tool available
without re-sending the full tool configuration.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_removal ⇒ Types::ToolRemovalBlock
A content block for removing a tool from the available tool set
mid-conversation. Each block references a single tool via its tool
field. Use within a system role message to remove a tool without
re-sending the full tool configuration.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_use ⇒ Types::ToolUseBlock
Information about a tool use request from a model.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
756 757 758 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 def unknown @unknown end |
#video ⇒ Types::VideoBlock
Video to include in the message.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 756 class ContentBlock < Struct.new( :text, :image, :document, :video, :audio, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :search_result, :tool_addition, :tool_removal, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class Audio < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class SearchResult < ContentBlock; end class ToolAddition < ContentBlock; end class ToolRemoval < ContentBlock; end class Unknown < ContentBlock; end end |