Class: Aws::BedrockRuntime::Types::ContentBlockDelta
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ContentBlockDelta
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
ContentBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ContentBlockDelta corresponding to the set member.
A block of content in a streaming response.
Defined Under Namespace
Classes: Citation, Image, ReasoningContent, Text, ToolResult, ToolUse, Unknown
Constant Summary collapse
- SENSITIVE =
[:reasoning_content]
Instance Attribute Summary collapse
-
#citation ⇒ Types::CitationsDelta
Incremental citation information that is streamed as part of the response generation process.
-
#image ⇒ Types::ImageBlockDelta
A streaming delta event containing incremental image data.
-
#reasoning_content ⇒ Types::ReasoningContentBlockDelta
Contains content regarding the reasoning that is carried out by the model.
-
#text ⇒ String
The content text.
-
#tool_result ⇒ Array<Types::ToolResultBlockDelta>
An incremental update that contains the results from a tool call.
-
#tool_use ⇒ Types::ToolUseBlockDelta
Information about a tool that the model is requesting to use.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#citation ⇒ Types::CitationsDelta
Incremental citation information that is streamed as part of the response generation process.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 826 class ContentBlockDelta < Struct.new( :text, :tool_use, :tool_result, :reasoning_content, :citation, :image, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlockDelta; end class ToolUse < ContentBlockDelta; end class ToolResult < ContentBlockDelta; end class ReasoningContent < ContentBlockDelta; end class Citation < ContentBlockDelta; end class Image < ContentBlockDelta; end class Unknown < ContentBlockDelta; end end |
#image ⇒ Types::ImageBlockDelta
A streaming delta event containing incremental image data.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 826 class ContentBlockDelta < Struct.new( :text, :tool_use, :tool_result, :reasoning_content, :citation, :image, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlockDelta; end class ToolUse < ContentBlockDelta; end class ToolResult < ContentBlockDelta; end class ReasoningContent < ContentBlockDelta; end class Citation < ContentBlockDelta; end class Image < ContentBlockDelta; end class Unknown < ContentBlockDelta; end end |
#reasoning_content ⇒ Types::ReasoningContentBlockDelta
Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 826 class ContentBlockDelta < Struct.new( :text, :tool_use, :tool_result, :reasoning_content, :citation, :image, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlockDelta; end class ToolUse < ContentBlockDelta; end class ToolResult < ContentBlockDelta; end class ReasoningContent < ContentBlockDelta; end class Citation < ContentBlockDelta; end class Image < ContentBlockDelta; end class Unknown < ContentBlockDelta; end end |
#text ⇒ String
The content text.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 826 class ContentBlockDelta < Struct.new( :text, :tool_use, :tool_result, :reasoning_content, :citation, :image, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlockDelta; end class ToolUse < ContentBlockDelta; end class ToolResult < ContentBlockDelta; end class ReasoningContent < ContentBlockDelta; end class Citation < ContentBlockDelta; end class Image < ContentBlockDelta; end class Unknown < ContentBlockDelta; end end |
#tool_result ⇒ Array<Types::ToolResultBlockDelta>
An incremental update that contains the results from a tool call.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 826 class ContentBlockDelta < Struct.new( :text, :tool_use, :tool_result, :reasoning_content, :citation, :image, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlockDelta; end class ToolUse < ContentBlockDelta; end class ToolResult < ContentBlockDelta; end class ReasoningContent < ContentBlockDelta; end class Citation < ContentBlockDelta; end class Image < ContentBlockDelta; end class Unknown < ContentBlockDelta; end end |
#tool_use ⇒ Types::ToolUseBlockDelta
Information about a tool that the model is requesting to use.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 826 class ContentBlockDelta < Struct.new( :text, :tool_use, :tool_result, :reasoning_content, :citation, :image, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlockDelta; end class ToolUse < ContentBlockDelta; end class ToolResult < ContentBlockDelta; end class ReasoningContent < ContentBlockDelta; end class Citation < ContentBlockDelta; end class Image < ContentBlockDelta; end class Unknown < ContentBlockDelta; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
826 827 828 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 826 def unknown @unknown end |