Class: Aws::BedrockRuntime::Types::ConverseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ConverseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_model_request_fields ⇒ Hash, ...
Additional inference parameters that the model supports, beyond the base set of inference parameters that ‘Converse` supports in the `inferenceConfig` field.
-
#additional_model_response_field_paths ⇒ Array<String>
Additional model parameters field paths to return in the response.
-
#inference_config ⇒ Types::InferenceConfiguration
Inference parameters to pass to the model.
-
#messages ⇒ Array<Types::Message>
The messages that you want to send to the model.
-
#model_id ⇒ String
The identifier for the model that you want to call.
-
#system ⇒ Array<Types::SystemContentBlock>
A system prompt to pass to the model.
-
#tool_config ⇒ Types::ToolConfiguration
Configuration information for the tools that the model can use when generating a response.
Instance Attribute Details
#additional_model_request_fields ⇒ Hash, ...
Additional inference parameters that the model supports, beyond the base set of inference parameters that ‘Converse` supports in the `inferenceConfig` field. For more information, see [Model parameters].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html
318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 318 class ConverseRequest < Struct.new( :model_id, :messages, :system, :inference_config, :tool_config, :additional_model_request_fields, :additional_model_response_field_paths) SENSITIVE = [] include Aws::Structure end |
#additional_model_response_field_paths ⇒ Array<String>
Additional model parameters field paths to return in the response. ‘Converse` returns the requested fields as a JSON Pointer object in the `additionalModelResultFields` field. The following is example JSON for `additionalModelResponseFieldPaths`.
‘[ “/stop_sequence” ]`
For information about the JSON Pointer syntax, see the [Internet Engineering Task Force (IETF)] documentation.
‘Converse` rejects an empty JSON Pointer or incorrectly structured JSON Pointer with a `400` error code. if the JSON Pointer is valid, but the requested field is not in the model response, it is ignored by `Converse`.
318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 318 class ConverseRequest < Struct.new( :model_id, :messages, :system, :inference_config, :tool_config, :additional_model_request_fields, :additional_model_response_field_paths) SENSITIVE = [] include Aws::Structure end |
#inference_config ⇒ Types::InferenceConfiguration
Inference parameters to pass to the model. ‘Converse` supports a base set of inference parameters. If you need to pass additional parameters that the model supports, use the `additionalModelRequestFields` request field.
318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 318 class ConverseRequest < Struct.new( :model_id, :messages, :system, :inference_config, :tool_config, :additional_model_request_fields, :additional_model_response_field_paths) SENSITIVE = [] include Aws::Structure end |
#messages ⇒ Array<Types::Message>
The messages that you want to send to the model.
318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 318 class ConverseRequest < Struct.new( :model_id, :messages, :system, :inference_config, :tool_config, :additional_model_request_fields, :additional_model_response_field_paths) SENSITIVE = [] include Aws::Structure end |
#model_id ⇒ String
The identifier for the model that you want to call.
The ‘modelId` to provide depends on the type of model that you use:
-
If you use a base model, specify the model ID or its ARN. For a list of model IDs for base models, see [Amazon Bedrock base model IDs (on-demand throughput)] in the Amazon Bedrock User Guide.
-
If you use a provisioned model, specify the ARN of the Provisioned Throughput. For more information, see [Run inference using a Provisioned Throughput] in the Amazon Bedrock User Guide.
-
If you use a custom model, first purchase Provisioned Throughput for it. Then specify the ARN of the resulting provisioned model. For more information, see [Use a custom model in Amazon Bedrock] in the Amazon Bedrock User Guide.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-ids.html#model-ids-arns [2]: docs.aws.amazon.com/bedrock/latest/userguide/prov-thru-use.html [3]: docs.aws.amazon.com/bedrock/latest/userguide/model-customization-use.html
318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 318 class ConverseRequest < Struct.new( :model_id, :messages, :system, :inference_config, :tool_config, :additional_model_request_fields, :additional_model_response_field_paths) SENSITIVE = [] include Aws::Structure end |
#system ⇒ Array<Types::SystemContentBlock>
A system prompt to pass to the model.
318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 318 class ConverseRequest < Struct.new( :model_id, :messages, :system, :inference_config, :tool_config, :additional_model_request_fields, :additional_model_response_field_paths) SENSITIVE = [] include Aws::Structure end |
#tool_config ⇒ Types::ToolConfiguration
Configuration information for the tools that the model can use when generating a response.
<note markdown=“1”> This field is only supported by Anthropic Claude 3, Cohere Command R, Cohere Command R+, and Mistral Large models.
</note>
318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 318 class ConverseRequest < Struct.new( :model_id, :messages, :system, :inference_config, :tool_config, :additional_model_request_fields, :additional_model_response_field_paths) SENSITIVE = [] include Aws::Structure end |