Class: Aws::BedrockRuntime::Types::ConverseResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ConverseResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_model_response_fields ⇒ Hash, ...
Additional fields in the response that are unique to the model.
-
#metrics ⇒ Types::ConverseMetrics
Metrics for the call to
Converse. -
#output ⇒ Types::ConverseOutput
The result from the call to
Converse. -
#performance_config ⇒ Types::PerformanceConfiguration
Model performance settings for the request.
-
#service_tier ⇒ Types::ServiceTier
Specifies the processing tier configuration used for serving the request.
-
#stop_reason ⇒ String
The reason why the model stopped generating output.
-
#trace ⇒ Types::ConverseTrace
A trace object that contains information about the Guardrail behavior.
-
#usage ⇒ Types::TokenUsage
The total number of tokens used in the call to
Converse.
Instance Attribute Details
#additional_model_response_fields ⇒ Hash, ...
Additional fields in the response that are unique to the model.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Types::ConverseMetrics
Metrics for the call to Converse.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |
#output ⇒ Types::ConverseOutput
The result from the call to Converse.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |
#performance_config ⇒ Types::PerformanceConfiguration
Model performance settings for the request.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |
#service_tier ⇒ Types::ServiceTier
Specifies the processing tier configuration used for serving the request.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |
#stop_reason ⇒ String
The reason why the model stopped generating output.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |
#trace ⇒ Types::ConverseTrace
A trace object that contains information about the Guardrail behavior.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |
#usage ⇒ Types::TokenUsage
The total number of tokens used in the call to Converse. The total
includes the tokens input to the model and the tokens generated by
the model.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1169 class ConverseResponse < Struct.new( :output, :stop_reason, :usage, :metrics, :additional_model_response_fields, :trace, :performance_config, :service_tier) SENSITIVE = [] include Aws::Structure end |