Class: Aws::BedrockRuntime::Types::ConverseStreamRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_request_fieldsHash, ...

Additional inference parameters that the model supports, beyond the base set of inference parameters that ‘ConverseStream` supports in the `inferenceConfig` field.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end

#additional_model_response_field_pathsArray<String>

Additional model parameters field paths to return in the response. ‘ConverseStream` returns the requested fields as a JSON Pointer object in the `additionalModelResponseFields` field. The following is example JSON for `additionalModelResponseFieldPaths`.

‘[ “/stop_sequence” ]`

For information about the JSON Pointer syntax, see the [Internet Engineering Task Force (IETF)] documentation.

‘ConverseStream` rejects an empty JSON Pointer or incorrectly structured JSON Pointer with a `400` error code. if the JSON Pointer is valid, but the requested field is not in the model response, it is ignored by `ConverseStream`.

[1]: datatracker.ietf.org/doc/html/rfc6901

Returns:

  • (Array<String>)


581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end

#guardrail_configTypes::GuardrailStreamConfiguration

Configuration information for a guardrail that you want to use in the request.



581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end

#inference_configTypes::InferenceConfiguration

Inference parameters to pass to the model. ‘ConverseStream` supports a base set of inference parameters. If you need to pass additional parameters that the model supports, use the `additionalModelRequestFields` request field.



581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end

#messagesArray<Types::Message>

The messages that you want to send to the model.

Returns:



581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end

#model_idString

The ID for the model.

The ‘modelId` to provide depends on the type of model that you use:

  • If you use a base model, specify the model ID or its ARN. For a list of model IDs for base models, see [Amazon Bedrock base model IDs (on-demand throughput)] in the Amazon Bedrock User Guide.

  • If you use a provisioned model, specify the ARN of the Provisioned Throughput. For more information, see [Run inference using a Provisioned Throughput] in the Amazon Bedrock User Guide.

  • If you use a custom model, first purchase Provisioned Throughput for it. Then specify the ARN of the resulting provisioned model. For more information, see [Use a custom model in Amazon Bedrock] in the Amazon Bedrock User Guide.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-ids.html#model-ids-arns [2]: docs.aws.amazon.com/bedrock/latest/userguide/prov-thru-use.html [3]: docs.aws.amazon.com/bedrock/latest/userguide/model-customization-use.html

Returns:

  • (String)


581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end

#systemArray<Types::SystemContentBlock>

A system prompt to send to the model.

Returns:



581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end

#tool_configTypes::ToolConfiguration

Configuration information for the tools that the model can use when generating a response.

<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.

</note>


581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 581

class ConverseStreamRequest < Struct.new(
  :model_id,
  :messages,
  :system,
  :inference_config,
  :tool_config,
  :guardrail_config,
  :additional_model_request_fields,
  :additional_model_response_field_paths)
  SENSITIVE = []
  include Aws::Structure
end