Class: Aws::BedrockRuntime::Types::CountTokensRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::CountTokensRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input ⇒ Types::CountTokensInput
The input for which to count tokens.
-
#model_id ⇒ String
The unique identifier or ARN of the foundation model to use for token counting.
Instance Attribute Details
#input ⇒ Types::CountTokensInput
The input for which to count tokens. The structure of this parameter
depends on whether you're counting tokens for an InvokeModel or
Converse request:
-
For
InvokeModelrequests, provide the request body in theinvokeModelfield -
For
Converserequests, provide the messages and system content in theconversefield
The input format must be compatible with the model specified in the
modelId parameter.
1544 1545 1546 1547 1548 1549 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1544 class CountTokensRequest < Struct.new( :model_id, :input) SENSITIVE = [] include Aws::Structure end |
#model_id ⇒ String
The unique identifier or ARN of the foundation model to use for token counting. Each model processes tokens differently, so the token count is specific to the model you specify.
1544 1545 1546 1547 1548 1549 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1544 class CountTokensRequest < Struct.new( :model_id, :input) SENSITIVE = [] include Aws::Structure end |