Class: Aws::BedrockRuntime::Types::CountTokensResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::CountTokensResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_tokens ⇒ Integer
The number of tokens in the provided input according to the specified model's tokenization rules.
Instance Attribute Details
#input_tokens ⇒ Integer
The number of tokens in the provided input according to the specified model's tokenization rules. This count represents the number of input tokens that would be processed if the same input were sent to the model in an inference request. Use this value to estimate costs and ensure your inputs stay within model token limits.
1562 1563 1564 1565 1566 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1562 class CountTokensResponse < Struct.new( :input_tokens) SENSITIVE = [] include Aws::Structure end |