Class: Aws::BedrockRuntime::Types::DocumentSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::DocumentSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
DocumentSource is a union - when making an API calls you must set exactly one of the members.
DocumentSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of DocumentSource corresponding to the set member.
Contains the content of a document.
Defined Under Namespace
Classes: Bytes, Content, S3Location, Text, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw bytes for the document.
-
#content ⇒ Array<Types::DocumentContentBlock>
The structured content of the document source, which may include various content blocks such as text, images, or other document elements.
-
#s3_location ⇒ Types::S3Location
The location of a document object in an Amazon S3 bucket.
-
#text ⇒ String
The text content of the document source.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw bytes for the document. If you use an Amazon Web Services SDK, you don't need to encode the bytes in base64.
1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1762 class DocumentSource < Struct.new( :bytes, :s3_location, :text, :content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class S3Location < DocumentSource; end class Text < DocumentSource; end class Content < DocumentSource; end class Unknown < DocumentSource; end end |
#content ⇒ Array<Types::DocumentContentBlock>
The structured content of the document source, which may include various content blocks such as text, images, or other document elements.
1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1762 class DocumentSource < Struct.new( :bytes, :s3_location, :text, :content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class S3Location < DocumentSource; end class Text < DocumentSource; end class Content < DocumentSource; end class Unknown < DocumentSource; end end |
#s3_location ⇒ Types::S3Location
The location of a document object in an Amazon S3 bucket. To see which models support S3 uploads, see Supported models and features for Converse.
1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1762 class DocumentSource < Struct.new( :bytes, :s3_location, :text, :content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class S3Location < DocumentSource; end class Text < DocumentSource; end class Content < DocumentSource; end class Unknown < DocumentSource; end end |
#text ⇒ String
The text content of the document source.
1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1762 class DocumentSource < Struct.new( :bytes, :s3_location, :text, :content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class S3Location < DocumentSource; end class Text < DocumentSource; end class Content < DocumentSource; end class Unknown < DocumentSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1762 1763 1764 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1762 def unknown @unknown end |