Class: Aws::BedrockRuntime::Types::GuardrailChecksPromptAttackResultEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

The evaluation result for a single prompt attack category.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString

The prompt attack category that was evaluated.

Returns:

  • (String)


2497
2498
2499
2500
2501
2502
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2497

class GuardrailChecksPromptAttackResultEntry < Struct.new(
  :category,
  :severity_score)
  SENSITIVE = []
  include Aws::Structure
end

#severity_scoreFloat

The severity score for the category, ranging from 0.0 to 1.0. Higher values indicate greater severity.

Returns:

  • (Float)


2497
2498
2499
2500
2501
2502
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2497

class GuardrailChecksPromptAttackResultEntry < Struct.new(
  :category,
  :severity_score)
  SENSITIVE = []
  include Aws::Structure
end