Class: Aws::BedrockRuntime::Types::GuardrailChecksPromptAttackUsage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

The text unit usage for the prompt attack check.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#text_unitsInteger

The number of text units consumed by the prompt attack check.

Returns:

  • (Integer)


2512
2513
2514
2515
2516
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2512

class GuardrailChecksPromptAttackUsage < Struct.new(
  :text_units)
  SENSITIVE = []
  include Aws::Structure
end