Class: Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
The sensitive information check results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#results ⇒ Array<Types::GuardrailChecksSensitiveInformationResultEntry>
The detected sensitive information entities.
-
#truncated ⇒ Boolean
Specifies whether the results were truncated because the number of detected entities exceeded the maximum limit.
Instance Attribute Details
#results ⇒ Array<Types::GuardrailChecksSensitiveInformationResultEntry>
The detected sensitive information entities.
2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2586 class GuardrailChecksSensitiveInformationResult < Struct.new( :results, :truncated) SENSITIVE = [] include Aws::Structure end |
#truncated ⇒ Boolean
Specifies whether the results were truncated because the number of detected entities exceeded the maximum limit.
2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2586 class GuardrailChecksSensitiveInformationResult < Struct.new( :results, :truncated) SENSITIVE = [] include Aws::Structure end |