Class: Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationResultEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

The detection result for a single sensitive information entity found in the evaluated messages.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#begin_offsetInteger

The start character offset of the detected entity within the content block.

Returns:

  • (Integer)


2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627

class GuardrailChecksSensitiveInformationResultEntry < Struct.new(
  :type,
  :confidence_score,
  :begin_offset,
  :end_offset,
  :message_index,
  :content_index)
  SENSITIVE = []
  include Aws::Structure
end

#confidence_scoreFloat

The confidence score for the detection, ranging from 0.0 to 1.0. Higher values indicate greater confidence.

Returns:

  • (Float)


2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627

class GuardrailChecksSensitiveInformationResultEntry < Struct.new(
  :type,
  :confidence_score,
  :begin_offset,
  :end_offset,
  :message_index,
  :content_index)
  SENSITIVE = []
  include Aws::Structure
end

#content_indexInteger

The zero-based index of the content block within the message where the entity was detected.

Returns:

  • (Integer)


2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627

class GuardrailChecksSensitiveInformationResultEntry < Struct.new(
  :type,
  :confidence_score,
  :begin_offset,
  :end_offset,
  :message_index,
  :content_index)
  SENSITIVE = []
  include Aws::Structure
end

#end_offsetInteger

The end character offset of the detected entity within the content block.

Returns:

  • (Integer)


2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627

class GuardrailChecksSensitiveInformationResultEntry < Struct.new(
  :type,
  :confidence_score,
  :begin_offset,
  :end_offset,
  :message_index,
  :content_index)
  SENSITIVE = []
  include Aws::Structure
end

#message_indexInteger

The zero-based index of the message in the input messages array where the entity was detected.

Returns:

  • (Integer)


2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627

class GuardrailChecksSensitiveInformationResultEntry < Struct.new(
  :type,
  :confidence_score,
  :begin_offset,
  :end_offset,
  :message_index,
  :content_index)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The PII entity type that was detected.

Returns:

  • (String)


2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627

class GuardrailChecksSensitiveInformationResultEntry < Struct.new(
  :type,
  :confidence_score,
  :begin_offset,
  :end_offset,
  :message_index,
  :content_index)
  SENSITIVE = []
  include Aws::Structure
end