Class: Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationUsage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

The text unit usage for the sensitive information check.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#text_unitsInteger

The number of text units consumed by the sensitive information check.

Returns:

  • (Integer)


2647
2648
2649
2650
2651
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2647

class GuardrailChecksSensitiveInformationUsage < Struct.new(
  :text_units)
  SENSITIVE = []
  include Aws::Structure
end