Class: Aws::BedrockRuntime::Types::GuardrailChecksUsageResults

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

The text unit usage for the guardrail checks evaluation, organized by check type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_filterTypes::GuardrailChecksContentFilterUsage

The text unit usage for the content filter check.



2670
2671
2672
2673
2674
2675
2676
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2670

class GuardrailChecksUsageResults < Struct.new(
  :content_filter,
  :prompt_attack,
  :sensitive_information)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_attackTypes::GuardrailChecksPromptAttackUsage

The text unit usage for the prompt attack check.



2670
2671
2672
2673
2674
2675
2676
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2670

class GuardrailChecksUsageResults < Struct.new(
  :content_filter,
  :prompt_attack,
  :sensitive_information)
  SENSITIVE = []
  include Aws::Structure
end

#sensitive_informationTypes::GuardrailChecksSensitiveInformationUsage

The text unit usage for the sensitive information check.



2670
2671
2672
2673
2674
2675
2676
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2670

class GuardrailChecksUsageResults < Struct.new(
  :content_filter,
  :prompt_attack,
  :sensitive_information)
  SENSITIVE = []
  include Aws::Structure
end