Class: Aws::BedrockRuntime::Types::GuardrailContentBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

GuardrailContentBlock is a union - when making an API calls you must set exactly one of the members.

The content block to be evaluated by the guardrail.

Defined Under Namespace

Classes: Image, Text, Unknown

Constant Summary collapse

SENSITIVE =
[:image]

Instance Attribute Summary collapse

Instance Attribute Details

#imageTypes::GuardrailImageBlock

Image within guardrail content block to be evaluated by the guardrail.



2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2740

class GuardrailContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailContentBlock; end
  class Image < GuardrailContentBlock; end
  class Unknown < GuardrailContentBlock; end
end

#textTypes::GuardrailTextBlock

Text within content block to be evaluated by the guardrail.



2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2740

class GuardrailContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailContentBlock; end
  class Image < GuardrailContentBlock; end
  class Unknown < GuardrailContentBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2740
2741
2742
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2740

def unknown
  @unknown
end