Class: Aws::BedrockRuntime::Types::GuardrailConverseContentBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

GuardrailConverseContentBlock is a union - when making an API calls you must set exactly one of the members.

Note:

GuardrailConverseContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of GuardrailConverseContentBlock corresponding to the set member.

A content block for selective guarding with the Converse or ConverseStream API operations.

Defined Under Namespace

Classes: Image, Text, Unknown

Constant Summary collapse

SENSITIVE =
[:image]

Instance Attribute Summary collapse

Instance Attribute Details

#imageTypes::GuardrailConverseImageBlock

Image within converse content block to be evaluated by the guardrail.



2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2859

class GuardrailConverseContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailConverseContentBlock; end
  class Image < GuardrailConverseContentBlock; end
  class Unknown < GuardrailConverseContentBlock; end
end

#textTypes::GuardrailConverseTextBlock

The text to guard.



2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2859

class GuardrailConverseContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailConverseContentBlock; end
  class Image < GuardrailConverseContentBlock; end
  class Unknown < GuardrailConverseContentBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2859
2860
2861
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2859

def unknown
  @unknown
end