Class: Aws::BedrockRuntime::Types::ImageSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ImageSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
ImageSource is a union - when making an API calls you must set exactly one of the members.
ImageSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ImageSource corresponding to the set member.
The source for an image.
Defined Under Namespace
Classes: Bytes, S3Location, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw image bytes for the image.
-
#s3_location ⇒ Types::S3Location
The location of an image object in an Amazon S3 bucket.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw image bytes for the image. If you use an AWS SDK, you don't need to encode the image bytes in base64.
3539 3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3539 class ImageSource < Struct.new( :bytes, :s3_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageSource; end class S3Location < ImageSource; end class Unknown < ImageSource; end end |
#s3_location ⇒ Types::S3Location
The location of an image object in an Amazon S3 bucket. To see which models support S3 uploads, see Supported models and features for Converse.
3539 3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3539 class ImageSource < Struct.new( :bytes, :s3_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageSource; end class S3Location < ImageSource; end class Unknown < ImageSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3539 3540 3541 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3539 def unknown @unknown end |