Class: Aws::BedrockRuntime::Types::InvokeGuardrailChecksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#checksTypes::GuardrailChecksConfig

The inline check configurations that specify which guardrail checks to run against the messages.



3637
3638
3639
3640
3641
3642
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3637

class InvokeGuardrailChecksRequest < Struct.new(
  :messages,
  :checks)
  SENSITIVE = []
  include Aws::Structure
end

#messagesArray<Types::GuardrailChecksMessage>

The messages to evaluate against the specified guardrail checks. Each message includes a role and one or more content blocks.

Returns:



3637
3638
3639
3640
3641
3642
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3637

class InvokeGuardrailChecksRequest < Struct.new(
  :messages,
  :checks)
  SENSITIVE = []
  include Aws::Structure
end