Class: Aws::BedrockRuntime::Types::InvokeModelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:body]

Instance Attribute Summary collapse

Instance Attribute Details

#acceptString

The desired MIME type of the inference body in the response. The default value is ‘application/json`.

Returns:

  • (String)


66
67
68
69
70
71
72
73
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 66

class InvokeModelRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end

#bodyString

Input data in the format specified in the content-type request header. To see the format and content of this field for different models, refer to [Inference parameters].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html

Returns:

  • (String)


66
67
68
69
70
71
72
73
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 66

class InvokeModelRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end

#content_typeString

The MIME type of the input data in the request. The default value is ‘application/json`.

Returns:

  • (String)


66
67
68
69
70
71
72
73
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 66

class InvokeModelRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end

#model_idString

Identifier of the model.

Returns:

  • (String)


66
67
68
69
70
71
72
73
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 66

class InvokeModelRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end