Class: Aws::BedrockRuntime::Types::InvokeModelTokensRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::InvokeModelTokensRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
The body of an InvokeModel API request for token counting. This
structure mirrors the input format for the InvokeModel operation,
allowing you to count tokens for raw text inference requests.
Constant Summary collapse
- SENSITIVE =
[:body]
Instance Attribute Summary collapse
-
#body ⇒ String
The request body to count tokens for, formatted according to the model's expected input format.
Instance Attribute Details
#body ⇒ String
The request body to count tokens for, formatted according to the model's expected input format. To learn about the input format for different models, see Model inference parameters and responses.
3847 3848 3849 3850 3851 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3847 class InvokeModelTokensRequest < Struct.new( :body) SENSITIVE = [:body] include Aws::Structure end |