Class: Aws::BedrockRuntime::Types::InvokeModelWithResponseStreamRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:body]

Instance Attribute Summary collapse

Instance Attribute Details

#acceptString

The desired MIME type of the inference body in the response. The default value is ‘application/json`.

Returns:

  • (String)


123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 123

class InvokeModelWithResponseStreamRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end

#bodyString

Inference input in the format specified by the content-type. To see the format and content of this field for different models, refer to [Inference parameters].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html

Returns:

  • (String)


123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 123

class InvokeModelWithResponseStreamRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end

#content_typeString

The MIME type of the input data in the request. The default value is ‘application/json`.

Returns:

  • (String)


123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 123

class InvokeModelWithResponseStreamRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end

#model_idString

Id of the model to invoke using the streaming request.

Returns:

  • (String)


123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 123

class InvokeModelWithResponseStreamRequest < Struct.new(
  :accept,
  :body,
  :content_type,
  :model_id)
  SENSITIVE = [:body]
  include Aws::Structure
end