Class: Aws::BedrockRuntime::Types::InvokeModelWithResponseStreamResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::InvokeModelWithResponseStreamResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ Types::ResponseStream
Inference response from the model in the format specified by the
contentTypeheader. -
#content_type ⇒ String
The MIME type of the inference result.
-
#performance_config_latency ⇒ String
Model performance settings for the request.
-
#service_tier ⇒ String
Specifies the processing tier type used for serving the request.
Instance Attribute Details
#body ⇒ Types::ResponseStream
Inference response from the model in the format specified by the
contentType header. To see the format and content of this field
for different models, refer to Inference parameters.
4035 4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4035 class InvokeModelWithResponseStreamResponse < Struct.new( :body, :content_type, :performance_config_latency, :service_tier) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
The MIME type of the inference result.
4035 4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4035 class InvokeModelWithResponseStreamResponse < Struct.new( :body, :content_type, :performance_config_latency, :service_tier) SENSITIVE = [] include Aws::Structure end |
#performance_config_latency ⇒ String
Model performance settings for the request.
4035 4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4035 class InvokeModelWithResponseStreamResponse < Struct.new( :body, :content_type, :performance_config_latency, :service_tier) SENSITIVE = [] include Aws::Structure end |
#service_tier ⇒ String
Specifies the processing tier type used for serving the request.
4035 4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4035 class InvokeModelWithResponseStreamResponse < Struct.new( :body, :content_type, :performance_config_latency, :service_tier) SENSITIVE = [] include Aws::Structure end |