Class: Aws::BedrockRuntime::Types::Message
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::Message
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
A message in the [Message] field. Use to send a message in a call to [Converse].
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Message.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ Array<Types::ContentBlock>
The message content.
-
#role ⇒ String
The role that the message plays in the message.
Instance Attribute Details
#content ⇒ Array<Types::ContentBlock>
The message content.
886 887 888 889 890 891 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 886 class Message < Struct.new( :role, :content) SENSITIVE = [] include Aws::Structure end |