Class: Aws::BedrockRuntime::Types::OutputConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Output configuration for a model response in a call to Converse or ConverseStream.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#effortString

The effort level for the model to use when generating a response. Higher effort levels allow the model to spend more time reasoning before responding. Supported values are low, medium, high, xhigh, and max.

When extended thinking is disabled, the effort level is capped at high. Use effort high or below, or enable thinking to use higher effort levels.

Returns:

  • (String)


4315
4316
4317
4318
4319
4320
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4315

class OutputConfig < Struct.new(
  :text_format,
  :effort)
  SENSITIVE = []
  include Aws::Structure
end

#text_formatTypes::OutputFormat

Structured output parameters to control the model's text response.

Returns:



4315
4316
4317
4318
4319
4320
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4315

class OutputConfig < Struct.new(
  :text_format,
  :effort)
  SENSITIVE = []
  include Aws::Structure
end