Class: Aws::BedrockRuntime::Types::PromptVariableValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::PromptVariableValues
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
PromptVariableValues is a union - when making an API calls you must set exactly one of the members.
Contains a map of variables in a prompt from Prompt management to an object containing the values to fill in for them when running model invocation. For more information, see How Prompt management works.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
The text value that the variable maps to.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
The text value that the variable maps to.
4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4422 class PromptVariableValues < Struct.new( :text, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < PromptVariableValues; end class Unknown < PromptVariableValues; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4422 4423 4424 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4422 def unknown @unknown end |