Class: Aws::BedrockRuntime::Types::SearchResultBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

A search result block that enables natural citations with proper source attribution for retrieved content.

This field is only supported by Anthropic Claude Opus 4.1, Opus 4, Sonnet 4.5, Sonnet 4, Sonnet 3.7, and 3.5 Haiku models.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#citationsTypes::CitationsConfig

Configuration setting for citations



4592
4593
4594
4595
4596
4597
4598
4599
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4592

class SearchResultBlock < Struct.new(
  :source,
  :title,
  :content,
  :citations)
  SENSITIVE = []
  include Aws::Structure
end

#contentArray<Types::SearchResultContentBlock>

An array of search result content block.



4592
4593
4594
4595
4596
4597
4598
4599
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4592

class SearchResultBlock < Struct.new(
  :source,
  :title,
  :content,
  :citations)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source URL or identifier for the content.

Returns:

  • (String)


4592
4593
4594
4595
4596
4597
4598
4599
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4592

class SearchResultBlock < Struct.new(
  :source,
  :title,
  :content,
  :citations)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

A descriptive title for the search result.

Returns:

  • (String)


4592
4593
4594
4595
4596
4597
4598
4599
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4592

class SearchResultBlock < Struct.new(
  :source,
  :title,
  :content,
  :citations)
  SENSITIVE = []
  include Aws::Structure
end