Class: Aws::BedrockRuntime::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Your request was throttled because of service-wide limitations. Resubmit your request later or in a different region. You can also purchase [Provisioned Throughput] to increase the rate or number of tokens you can process.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/prov-throughput.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



1901
1902
1903
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1901

def event_type
  @event_type
end

#messageString

Returns:

  • (String)


1901
1902
1903
1904
1905
1906
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1901

class ThrottlingException < Struct.new(
  :message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end