Class: Aws::BedrockRuntime::Types::Tool
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::Tool
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
Tool is a union - when making an API calls you must set exactly one of the members.
Information about a tool that you can use with the Converse API.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1558 class Tool < Struct.new( :tool_spec, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ToolSpec < Tool; end class Unknown < Tool; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1558 1559 1560 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1558 def unknown @unknown end |