Class: Aws::BedrockRuntime::Types::ToolAdditionBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

A content block for adding a tool to the available tool set mid-conversation. Each block references a single tool via its tool field. Use within a system role message to make a tool available without re-sending the full tool configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#toolTypes::ToolReference

A reference to the tool to add to the available tool set.



4960
4961
4962
4963
4964
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4960

class ToolAdditionBlock < Struct.new(
  :tool)
  SENSITIVE = []
  include Aws::Structure
end