Class: Aws::BedrockRuntime::Types::ToolChoice
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolChoice
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
ToolChoice is a union - when making an API calls you must set exactly one of the members.
Forces a model to use a tool.
Defined Under Namespace
Classes: Any, Auto, Tool, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
-
#auto ⇒ Types::AutoToolChoice
The Model automatically decides if a tool should be called or to whether to generate text instead.
-
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1164 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#auto ⇒ Types::AutoToolChoice
The Model automatically decides if a tool should be called or to whether to generate text instead.
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1164 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1164 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1164 1165 1166 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1164 def unknown @unknown end |