Class: Aws::BedrockRuntime::Types::ToolConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Configuration information for the tools that you pass to a model. For more information, see Tool use (function calling) in the Amazon Bedrock User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tool_choice ⇒ Types::ToolChoice
If supported by model, forces the model to request a tool.
-
#tools ⇒ Array<Types::Tool>
An array of tools that you want to pass to a model.
Instance Attribute Details
#tool_choice ⇒ Types::ToolChoice
If supported by model, forces the model to request a tool.
5025 5026 5027 5028 5029 5030 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5025 class ToolConfiguration < Struct.new( :tools, :tool_choice) SENSITIVE = [] include Aws::Structure end |
#tools ⇒ Array<Types::Tool>
An array of tools that you want to pass to a model.
5025 5026 5027 5028 5029 5030 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5025 class ToolConfiguration < Struct.new( :tools, :tool_choice) SENSITIVE = [] include Aws::Structure end |