Class: Aws::BedrockRuntime::Types::ToolInputSchema

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

ToolInputSchema is a union - when making an API calls you must set exactly one of the members.

The schema for the tool. The top level schema type must be object. For more information, see Call a tool with the Converse API in the Amazon Bedrock User Guide.

Defined Under Namespace

Classes: Json, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#jsonHash, ...

The JSON schema for the tool. For more information, see JSON Schema Reference.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5053

class ToolInputSchema < Struct.new(
  :json,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Json < ToolInputSchema; end
  class Unknown < ToolInputSchema; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5053
5054
5055
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5053

def unknown
  @unknown
end