Class: Aws::BedrockRuntime::Types::ToolReference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

A reference to a tool in the tool configuration. Used with ToolAdditionBlock and ToolRemovalBlock to identify which tool to add or remove mid-conversation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the tool. Must match the name of a tool declared in the top-level tool configuration.

Returns:

  • (String)


5084
5085
5086
5087
5088
5089
5090
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5084

class ToolReference < Struct.new(
  :type,
  :name,
  :server_name)
  SENSITIVE = []
  include Aws::Structure
end

#server_nameString

The name of the MCP server that provides the tool. Required when referencing an MCP tool.

Returns:

  • (String)


5084
5085
5086
5087
5088
5089
5090
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5084

class ToolReference < Struct.new(
  :type,
  :name,
  :server_name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of tool reference.

Returns:

  • (String)


5084
5085
5086
5087
5088
5089
5090
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5084

class ToolReference < Struct.new(
  :type,
  :name,
  :server_name)
  SENSITIVE = []
  include Aws::Structure
end