Class: Aws::BedrockRuntime::Types::ToolResultBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

A tool result block that contains the results for a tool request that the model previously made. For more information, see Call a tool with the Converse API in the Amazon Bedrock User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentArray<Types::ToolResultContentBlock>

The content for tool result content block.

Returns:



5140
5141
5142
5143
5144
5145
5146
5147
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5140

class ToolResultBlock < Struct.new(
  :tool_use_id,
  :content,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status for the tool result content block.

This field is only supported by Amazon Nova and Anthropic Claude 3 and 4 models.

Returns:

  • (String)


5140
5141
5142
5143
5144
5145
5146
5147
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5140

class ToolResultBlock < Struct.new(
  :tool_use_id,
  :content,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#tool_use_idString

The ID of the tool request that this is the result for.

Returns:

  • (String)


5140
5141
5142
5143
5144
5145
5146
5147
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5140

class ToolResultBlock < Struct.new(
  :tool_use_id,
  :content,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type for the tool result content block.

Returns:

  • (String)


5140
5141
5142
5143
5144
5145
5146
5147
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5140

class ToolResultBlock < Struct.new(
  :tool_use_id,
  :content,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end