Class: Aws::BedrockRuntime::Types::ToolResultBlockDelta
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolResultBlockDelta
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
ToolResultBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ToolResultBlockDelta corresponding to the set member.
Contains incremental updates to tool results information during streaming responses. This allows clients to build up tool results data progressively as the response is generated.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#json ⇒ Hash, ...
The JSON schema for the tool result content block.
-
#text ⇒ String
The reasoning the model used to return the output.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#json ⇒ Hash, ...
The JSON schema for the tool result content block. see [JSON Schema Reference].
5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5076 class ToolResultBlockDelta < Struct.new( :text, :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ToolResultBlockDelta; end class Json < ToolResultBlockDelta; end class Unknown < ToolResultBlockDelta; end end |
#text ⇒ String
The reasoning the model used to return the output.
5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5076 class ToolResultBlockDelta < Struct.new( :text, :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ToolResultBlockDelta; end class Json < ToolResultBlockDelta; end class Unknown < ToolResultBlockDelta; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5076 5077 5078 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5076 def unknown @unknown end |