Class: Aws::BedrockRuntime::Types::WebLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::WebLocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Provides the URL and domain information for the website that was cited when performing a web search.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain that was cited when performing a web search.
-
#url ⇒ String
The URL that was cited when performing a web search.
Instance Attribute Details
#domain ⇒ String
The domain that was cited when performing a web search.
5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5385 class WebLocation < Struct.new( :url, :domain) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL that was cited when performing a web search.
5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5385 class WebLocation < Struct.new( :url, :domain) SENSITIVE = [] include Aws::Structure end |