Module: Aws::BedrockRuntime::Types

Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AnyToolChoice, AppliedGuardrailDetails, ApplyGuardrailRequest, ApplyGuardrailResponse, AsyncInvokeOutputDataConfig, AsyncInvokeS3OutputDataConfig, AsyncInvokeSummary, AudioBlock, AudioSource, AutoToolChoice, BidirectionalInputPayloadPart, BidirectionalOutputPayloadPart, CacheDetail, CachePointBlock, Citation, CitationGeneratedContent, CitationLocation, CitationSourceContent, CitationSourceContentDelta, CitationsConfig, CitationsContentBlock, CitationsDelta, ConflictException, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTokensRequest, ConverseTrace, CountTokensInput, CountTokensRequest, CountTokensResponse, DocumentBlock, DocumentCharLocation, DocumentChunkLocation, DocumentContentBlock, DocumentPageLocation, DocumentSource, ErrorBlock, GetAsyncInvokeRequest, GetAsyncInvokeResponse, GuardrailAssessment, GuardrailAutomatedReasoningFinding, GuardrailAutomatedReasoningImpossibleFinding, GuardrailAutomatedReasoningInputTextReference, GuardrailAutomatedReasoningInvalidFinding, GuardrailAutomatedReasoningLogicWarning, GuardrailAutomatedReasoningNoTranslationsFinding, GuardrailAutomatedReasoningPolicyAssessment, GuardrailAutomatedReasoningRule, GuardrailAutomatedReasoningSatisfiableFinding, GuardrailAutomatedReasoningScenario, GuardrailAutomatedReasoningStatement, GuardrailAutomatedReasoningTooComplexFinding, GuardrailAutomatedReasoningTranslation, GuardrailAutomatedReasoningTranslationAmbiguousFinding, GuardrailAutomatedReasoningTranslationOption, GuardrailAutomatedReasoningValidFinding, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseImageBlock, GuardrailConverseImageSource, GuardrailConverseTextBlock, GuardrailCoverage, GuardrailCustomWord, GuardrailImageBlock, GuardrailImageCoverage, GuardrailImageSource, GuardrailInvocationMetrics, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTextCharactersCoverage, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageBlockDelta, ImageBlockStart, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelTokensRequest, InvokeModelWithBidirectionalStreamInput, InvokeModelWithBidirectionalStreamOutput, InvokeModelWithBidirectionalStreamRequest, InvokeModelWithBidirectionalStreamResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, JsonSchemaDefinition, ListAsyncInvokesRequest, ListAsyncInvokesResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, OutputConfig, OutputFormat, OutputFormatStructure, PayloadPart, PerformanceConfiguration, PromptRouterTrace, PromptVariableValues, ReasoningContentBlock, ReasoningContentBlockDelta, ReasoningTextBlock, ResourceNotFoundException, ResponseStream, S3Location, SearchResultBlock, SearchResultContentBlock, SearchResultLocation, ServiceQuotaExceededException, ServiceTier, ServiceUnavailableException, SpecificToolChoice, StartAsyncInvokeRequest, StartAsyncInvokeResponse, SystemContentBlock, SystemTool, Tag, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultBlockDelta, ToolResultBlockStart, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException, VideoBlock, VideoSource, WebLocation

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_response_fieldsHash, ...

The additional model response fields.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3763

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#anyTypes::AnyToolChoice

The model must request at least one tool (no text is generated).



4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4526

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#audioTypes::AudioBlock

An audio content block containing audio data in the conversation.

Returns:



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#autoTypes::AutoToolChoice

(Default). The Model automatically decides if a tool should be called or whether to generate text instead.



4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4526

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#bytesString

Video content encoded in base64.

Returns:

  • (String)


315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 315

class AudioSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < AudioSource; end
  class S3Location < AudioSource; end
  class Unknown < AudioSource; end
end

#cache_pointTypes::CachePointBlock

CachePoint to include in the tool configuration.



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#citationTypes::CitationsDelta

Incremental citation information that is streamed as part of the response generation process.



808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 808

class ContentBlockDelta < Struct.new(
  :text,
  :tool_use,
  :tool_result,
  :reasoning_content,
  :citation,
  :image,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlockDelta; end
  class ToolUse < ContentBlockDelta; end
  class ToolResult < ContentBlockDelta; end
  class ReasoningContent < ContentBlockDelta; end
  class Citation < ContentBlockDelta; end
  class Image < ContentBlockDelta; end
  class Unknown < ContentBlockDelta; end
end

#citations_contentTypes::CitationsContentBlock

A content block that contains both generated text and associated citation information, providing traceability between the response and source documents.



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#contentArray<Types::DocumentContentBlock>

The structured content of the document source, which may include various content blocks such as text, images, or other document elements.

Returns:



1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1744

class DocumentSource < Struct.new(
  :bytes,
  :s3_location,
  :text,
  :content,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < DocumentSource; end
  class S3Location < DocumentSource; end
  class Text < DocumentSource; end
  class Content < DocumentSource; end
  class Unknown < DocumentSource; end
end

#content_block_indexInteger

The index for a content block.

Returns:

  • (Integer)


841
842
843
844
845
846
847
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 841

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#converseTypes::ConverseTokensRequest

A ‘Converse` request for which to count tokens. Use this field when you want to count tokens for a conversation-based input that would be sent to the `Converse` operation.



1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1490

class CountTokensInput < Struct.new(
  :invoke_model,
  :converse,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class InvokeModel < CountTokensInput; end
  class Converse < CountTokensInput; end
  class Unknown < CountTokensInput; end
end

#deltaTypes::ContentBlockDelta

The delta for a content block delta event.



841
842
843
844
845
846
847
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 841

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#documentTypes::DocumentBlock

A tool result that is a document.



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#document_charTypes::DocumentCharLocation

The character-level location within the document where the cited content is found.



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 515

class CitationLocation < Struct.new(
  :web,
  :document_char,
  :document_page,
  :document_chunk,
  :search_result_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Web < CitationLocation; end
  class DocumentChar < CitationLocation; end
  class DocumentPage < CitationLocation; end
  class DocumentChunk < CitationLocation; end
  class SearchResultLocation < CitationLocation; end
  class Unknown < CitationLocation; end
end

#document_chunkTypes::DocumentChunkLocation

The chunk-level location within the document where the cited content is found, typically used for documents that have been segmented into logical chunks.



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 515

class CitationLocation < Struct.new(
  :web,
  :document_char,
  :document_page,
  :document_chunk,
  :search_result_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Web < CitationLocation; end
  class DocumentChar < CitationLocation; end
  class DocumentPage < CitationLocation; end
  class DocumentChunk < CitationLocation; end
  class SearchResultLocation < CitationLocation; end
  class Unknown < CitationLocation; end
end

#document_pageTypes::DocumentPageLocation

The page-level location within the document where the cited content is found.



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 515

class CitationLocation < Struct.new(
  :web,
  :document_char,
  :document_page,
  :document_chunk,
  :search_result_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Web < CitationLocation; end
  class DocumentChar < CitationLocation; end
  class DocumentPage < CitationLocation; end
  class DocumentChunk < CitationLocation; end
  class SearchResultLocation < CitationLocation; end
  class Unknown < CitationLocation; end
end

#guard_contentTypes::GuardrailConverseContentBlock

A content block to assess with the guardrail. Use with the

Converse][1

or [ConverseStream] API operations.

For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#imageTypes::ImageBlock

A tool result that is an image.

<note markdown=“1”> This field is only supported by Amazon Nova and Anthropic Claude 3 and 4 models.

</note>

Returns:



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#impossibleTypes::GuardrailAutomatedReasoningImpossibleFinding

Contains the result when the automated reasoning evaluation determines that no valid logical conclusions can be drawn due to contradictions in the premises or policy rules themselves.



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1945

class GuardrailAutomatedReasoningFinding < Struct.new(
  :valid,
  :invalid,
  :satisfiable,
  :impossible,
  :translation_ambiguous,
  :too_complex,
  :no_translations,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Valid < GuardrailAutomatedReasoningFinding; end
  class Invalid < GuardrailAutomatedReasoningFinding; end
  class Satisfiable < GuardrailAutomatedReasoningFinding; end
  class Impossible < GuardrailAutomatedReasoningFinding; end
  class TranslationAmbiguous < GuardrailAutomatedReasoningFinding; end
  class TooComplex < GuardrailAutomatedReasoningFinding; end
  class NoTranslations < GuardrailAutomatedReasoningFinding; end
  class Unknown < GuardrailAutomatedReasoningFinding; end
end

#invalidTypes::GuardrailAutomatedReasoningInvalidFinding

Contains the result when the automated reasoning evaluation determines that the claims in the input are logically invalid and contradict the established premises or policy rules.



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1945

class GuardrailAutomatedReasoningFinding < Struct.new(
  :valid,
  :invalid,
  :satisfiable,
  :impossible,
  :translation_ambiguous,
  :too_complex,
  :no_translations,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Valid < GuardrailAutomatedReasoningFinding; end
  class Invalid < GuardrailAutomatedReasoningFinding; end
  class Satisfiable < GuardrailAutomatedReasoningFinding; end
  class Impossible < GuardrailAutomatedReasoningFinding; end
  class TranslationAmbiguous < GuardrailAutomatedReasoningFinding; end
  class TooComplex < GuardrailAutomatedReasoningFinding; end
  class NoTranslations < GuardrailAutomatedReasoningFinding; end
  class Unknown < GuardrailAutomatedReasoningFinding; end
end

#invoke_modelTypes::InvokeModelTokensRequest

An ‘InvokeModel` request for which to count tokens. Use this field when you want to count tokens for a raw text input that would be sent to the `InvokeModel` operation.



1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1490

class CountTokensInput < Struct.new(
  :invoke_model,
  :converse,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class InvokeModel < CountTokensInput; end
  class Converse < CountTokensInput; end
  class Unknown < CountTokensInput; end
end

#jsonHash, ...

A tool result that is JSON format data.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


4587
4588
4589
4590
4591
4592
4593
4594
4595
4596
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4587

class ToolInputSchema < Struct.new(
  :json,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Json < ToolInputSchema; end
  class Unknown < ToolInputSchema; end
end

#json_schemaTypes::JsonSchemaDefinition

A JSON schema structure that the model’s output must adhere to.



3902
3903
3904
3905
3906
3907
3908
3909
3910
3911
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3902

class OutputFormatStructure < Struct.new(
  :json_schema,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JsonSchema < OutputFormatStructure; end
  class Unknown < OutputFormatStructure; end
end

#messageString

Returns:

  • (String)


949
950
951
952
953
954
955
956
957
958
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 949

class ConverseOutput < Struct.new(
  :message,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Message < ConverseOutput; end
  class Unknown < ConverseOutput; end
end

#metricsTypes::ConverseStreamMetrics

The metrics for the conversation stream metadata event.



1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1195

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :service_tier,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#no_translationsTypes::GuardrailAutomatedReasoningNoTranslationsFinding

Contains the result when the automated reasoning evaluation cannot extract any relevant logical information from the input that can be validated against the policy rules.



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1945

class GuardrailAutomatedReasoningFinding < Struct.new(
  :valid,
  :invalid,
  :satisfiable,
  :impossible,
  :translation_ambiguous,
  :too_complex,
  :no_translations,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Valid < GuardrailAutomatedReasoningFinding; end
  class Invalid < GuardrailAutomatedReasoningFinding; end
  class Satisfiable < GuardrailAutomatedReasoningFinding; end
  class Impossible < GuardrailAutomatedReasoningFinding; end
  class TranslationAmbiguous < GuardrailAutomatedReasoningFinding; end
  class TooComplex < GuardrailAutomatedReasoningFinding; end
  class NoTranslations < GuardrailAutomatedReasoningFinding; end
  class Unknown < GuardrailAutomatedReasoningFinding; end
end

#original_messageString

The original message.

Returns:

  • (String)


3829
3830
3831
3832
3833
3834
3835
3836
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3829

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#original_status_codeInteger

The original status code.

Returns:

  • (Integer)


3829
3830
3831
3832
3833
3834
3835
3836
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3829

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#performance_configTypes::PerformanceConfiguration

Model performance configuration metadata for the conversation stream event.



1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1195

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :service_tier,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#reasoning_contentTypes::ReasoningContentBlockDelta

Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#reasoning_textTypes::ReasoningTextBlock

The reasoning that the model used to return the output.



4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4005

class ReasoningContentBlock < Struct.new(
  :reasoning_text,
  :redacted_content,
  :unknown)
  SENSITIVE = [:reasoning_text]
  include Aws::Structure
  include Aws::Structure::Union

  class ReasoningText < ReasoningContentBlock; end
  class RedactedContent < ReasoningContentBlock; end
  class Unknown < ReasoningContentBlock; end
end

#redacted_contentString

The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.

Returns:

  • (String)


4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4005

class ReasoningContentBlock < Struct.new(
  :reasoning_text,
  :redacted_content,
  :unknown)
  SENSITIVE = [:reasoning_text]
  include Aws::Structure
  include Aws::Structure::Union

  class ReasoningText < ReasoningContentBlock; end
  class RedactedContent < ReasoningContentBlock; end
  class Unknown < ReasoningContentBlock; end
end

#roleString

The role for the message.

Returns:

  • (String)


3744
3745
3746
3747
3748
3749
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3744

class MessageStartEvent < Struct.new(
  :role,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationTypes::S3Location

The location of a video object in an Amazon S3 bucket. To see which models support S3 uploads, see [Supported models and features for Converse].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/conversation-inference-supported-models-features.html

Returns:



315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 315

class AudioSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < AudioSource; end
  class S3Location < AudioSource; end
  class Unknown < AudioSource; end
end

#s3_output_data_configTypes::AsyncInvokeS3OutputDataConfig

A storage location for the output data in an S3 bucket



174
175
176
177
178
179
180
181
182
183
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 174

class AsyncInvokeOutputDataConfig < Struct.new(
  :s3_output_data_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3OutputDataConfig < AsyncInvokeOutputDataConfig; end
  class Unknown < AsyncInvokeOutputDataConfig; end
end

#satisfiableTypes::GuardrailAutomatedReasoningSatisfiableFinding

Contains the result when the automated reasoning evaluation determines that the claims in the input could be either true or false depending on additional assumptions not provided in the input context.



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1945

class GuardrailAutomatedReasoningFinding < Struct.new(
  :valid,
  :invalid,
  :satisfiable,
  :impossible,
  :translation_ambiguous,
  :too_complex,
  :no_translations,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Valid < GuardrailAutomatedReasoningFinding; end
  class Invalid < GuardrailAutomatedReasoningFinding; end
  class Satisfiable < GuardrailAutomatedReasoningFinding; end
  class Impossible < GuardrailAutomatedReasoningFinding; end
  class TranslationAmbiguous < GuardrailAutomatedReasoningFinding; end
  class TooComplex < GuardrailAutomatedReasoningFinding; end
  class NoTranslations < GuardrailAutomatedReasoningFinding; end
  class Unknown < GuardrailAutomatedReasoningFinding; end
end

#search_resultTypes::SearchResultBlock

A tool result that is a search result.



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#search_result_locationTypes::SearchResultLocation

The search result location where the cited content is found, including the search result index and block positions within the content array.



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 515

class CitationLocation < Struct.new(
  :web,
  :document_char,
  :document_page,
  :document_chunk,
  :search_result_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Web < CitationLocation; end
  class DocumentChar < CitationLocation; end
  class DocumentPage < CitationLocation; end
  class DocumentChunk < CitationLocation; end
  class SearchResultLocation < CitationLocation; end
  class Unknown < CitationLocation; end
end

#service_tierTypes::ServiceTier

Specifies the processing tier configuration used for serving the request.

Returns:



1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1195

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :service_tier,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#signatureString

A token that verifies that the reasoning text was generated by the model. If you pass a reasoning block back to the API in a multi-turn conversation, include the text and its signature unmodified.

Returns:

  • (String)


4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4043

class ReasoningContentBlockDelta < Struct.new(
  :text,
  :redacted_content,
  :signature,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ReasoningContentBlockDelta; end
  class RedactedContent < ReasoningContentBlockDelta; end
  class Signature < ReasoningContentBlockDelta; end
  class Unknown < ReasoningContentBlockDelta; end
end

#startTypes::ContentBlockStart

Start information about a content block start event.



894
895
896
897
898
899
900
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 894

class ContentBlockStartEvent < Struct.new(
  :start,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#stop_reasonString

The reason why the model stopped generating output.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3763

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#system_toolTypes::SystemTool

Specifies the system-defined tool that you want use.

Returns:



4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
4497
4498
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4485

class Tool < Struct.new(
  :tool_spec,
  :system_tool,
  :cache_point,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ToolSpec < Tool; end
  class SystemTool < Tool; end
  class CachePoint < Tool; end
  class Unknown < Tool; end
end

#textString

A tool result that is text.

Returns:

  • (String)


467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 467

class CitationGeneratedContent < Struct.new(
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < CitationGeneratedContent; end
  class Unknown < CitationGeneratedContent; end
end

#too_complexTypes::GuardrailAutomatedReasoningTooComplexFinding

Contains the result when the automated reasoning evaluation cannot process the input due to its complexity or volume exceeding the system’s processing capacity for logical analysis.



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1945

class GuardrailAutomatedReasoningFinding < Struct.new(
  :valid,
  :invalid,
  :satisfiable,
  :impossible,
  :translation_ambiguous,
  :too_complex,
  :no_translations,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Valid < GuardrailAutomatedReasoningFinding; end
  class Invalid < GuardrailAutomatedReasoningFinding; end
  class Satisfiable < GuardrailAutomatedReasoningFinding; end
  class Impossible < GuardrailAutomatedReasoningFinding; end
  class TranslationAmbiguous < GuardrailAutomatedReasoningFinding; end
  class TooComplex < GuardrailAutomatedReasoningFinding; end
  class NoTranslations < GuardrailAutomatedReasoningFinding; end
  class Unknown < GuardrailAutomatedReasoningFinding; end
end

#toolTypes::SpecificToolChoice

The Model must request the specified tool. Only supported by Anthropic Claude 3 and Amazon Nova models.



4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4526

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#tool_resultTypes::ToolResultBlockStart

The



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#tool_specTypes::ToolSpecification

The specfication for the tool.



4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
4497
4498
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4485

class Tool < Struct.new(
  :tool_spec,
  :system_tool,
  :cache_point,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ToolSpec < Tool; end
  class SystemTool < Tool; end
  class CachePoint < Tool; end
  class Unknown < Tool; end
end

#tool_useTypes::ToolUseBlockStart

Information about a tool that the model is requesting to use.



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#traceTypes::ConverseStreamTrace

The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1195

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :service_tier,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#translation_ambiguousTypes::GuardrailAutomatedReasoningTranslationAmbiguousFinding

Contains the result when the automated reasoning evaluation detects that the input has multiple valid logical interpretations, requiring additional context or clarification to proceed with validation.



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1945

class GuardrailAutomatedReasoningFinding < Struct.new(
  :valid,
  :invalid,
  :satisfiable,
  :impossible,
  :translation_ambiguous,
  :too_complex,
  :no_translations,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Valid < GuardrailAutomatedReasoningFinding; end
  class Invalid < GuardrailAutomatedReasoningFinding; end
  class Satisfiable < GuardrailAutomatedReasoningFinding; end
  class Impossible < GuardrailAutomatedReasoningFinding; end
  class TranslationAmbiguous < GuardrailAutomatedReasoningFinding; end
  class TooComplex < GuardrailAutomatedReasoningFinding; end
  class NoTranslations < GuardrailAutomatedReasoningFinding; end
  class Unknown < GuardrailAutomatedReasoningFinding; end
end

#usageTypes::TokenUsage

Usage information for the conversation stream event.

Returns:



1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1195

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :service_tier,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#validTypes::GuardrailAutomatedReasoningValidFinding

Contains the result when the automated reasoning evaluation determines that the claims in the input are logically valid and definitively true based on the provided premises and policy rules.



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1945

class GuardrailAutomatedReasoningFinding < Struct.new(
  :valid,
  :invalid,
  :satisfiable,
  :impossible,
  :translation_ambiguous,
  :too_complex,
  :no_translations,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Valid < GuardrailAutomatedReasoningFinding; end
  class Invalid < GuardrailAutomatedReasoningFinding; end
  class Satisfiable < GuardrailAutomatedReasoningFinding; end
  class Impossible < GuardrailAutomatedReasoningFinding; end
  class TranslationAmbiguous < GuardrailAutomatedReasoningFinding; end
  class TooComplex < GuardrailAutomatedReasoningFinding; end
  class NoTranslations < GuardrailAutomatedReasoningFinding; end
  class Unknown < GuardrailAutomatedReasoningFinding; end
end

#videoTypes::VideoBlock

A tool result that is video.

Returns:



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 742

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :audio,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :citations_content,
  :search_result,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class Audio < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class CitationsContent < ContentBlock; end
  class SearchResult < ContentBlock; end
  class Unknown < ContentBlock; end
end

#webTypes::WebLocation

The web URL that was cited for this reference.

Returns:



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 515

class CitationLocation < Struct.new(
  :web,
  :document_char,
  :document_page,
  :document_chunk,
  :search_result_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Web < CitationLocation; end
  class DocumentChar < CitationLocation; end
  class DocumentPage < CitationLocation; end
  class DocumentChunk < CitationLocation; end
  class SearchResultLocation < CitationLocation; end
  class Unknown < CitationLocation; end
end