Module: Aws::BedrockRuntime::Types
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AnyToolChoice, ApplyGuardrailRequest, ApplyGuardrailResponse, AsyncInvokeOutputDataConfig, AsyncInvokeS3OutputDataConfig, AsyncInvokeSummary, AutoToolChoice, BidirectionalInputPayloadPart, BidirectionalOutputPayloadPart, CachePointBlock, Citation, CitationGeneratedContent, CitationLocation, CitationSourceContent, CitationSourceContentDelta, CitationsConfig, CitationsContentBlock, CitationsDelta, ConflictException, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTrace, DocumentBlock, DocumentCharLocation, DocumentChunkLocation, DocumentContentBlock, DocumentPageLocation, DocumentSource, GetAsyncInvokeRequest, GetAsyncInvokeResponse, GuardrailAssessment, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseImageBlock, GuardrailConverseImageSource, GuardrailConverseTextBlock, GuardrailCoverage, GuardrailCustomWord, GuardrailImageBlock, GuardrailImageCoverage, GuardrailImageSource, GuardrailInvocationMetrics, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTextCharactersCoverage, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithBidirectionalStreamInput, InvokeModelWithBidirectionalStreamOutput, InvokeModelWithBidirectionalStreamRequest, InvokeModelWithBidirectionalStreamResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, ListAsyncInvokesRequest, ListAsyncInvokesResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, PerformanceConfiguration, PromptRouterTrace, PromptVariableValues, ReasoningContentBlock, ReasoningContentBlockDelta, ReasoningTextBlock, ResourceNotFoundException, ResponseStream, S3Location, ServiceQuotaExceededException, ServiceUnavailableException, SpecificToolChoice, StartAsyncInvokeRequest, StartAsyncInvokeResponse, SystemContentBlock, Tag, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException, VideoBlock, VideoSource
Instance Attribute Summary collapse
-
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
-
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
-
#auto ⇒ Types::AutoToolChoice
(Default).
-
#bytes ⇒ String
Video content encoded in base64.
-
#cache_point ⇒ Types::CachePointBlock
CachePoint to include in the tool configuration.
-
#citation ⇒ Types::CitationsDelta
Incremental citation information that is streamed as part of the response generation process.
-
#citations_content ⇒ Types::CitationsContentBlock
A content block that contains both generated text and associated citation information, providing traceability between the response and source documents.
-
#content ⇒ Array<Types::DocumentContentBlock>
The structured content of the document source, which may include various content blocks such as text, images, or other document elements.
-
#content_block_index ⇒ Integer
The index for a content block.
-
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
-
#document ⇒ Types::DocumentBlock
A tool result that is a document.
-
#document_char ⇒ Types::DocumentCharLocation
The character-level location within the document where the cited content is found.
-
#document_chunk ⇒ Types::DocumentChunkLocation
The chunk-level location within the document where the cited content is found, typically used for documents that have been segmented into logical chunks.
-
#document_page ⇒ Types::DocumentPageLocation
The page-level location within the document where the cited content is found.
-
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail.
-
#image ⇒ Types::ImageBlock
A tool result that is an image.
-
#json ⇒ Hash, ...
A tool result that is JSON format data.
- #message ⇒ String
-
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
-
#original_message ⇒ String
The original message.
-
#original_status_code ⇒ Integer
The original status code.
-
#performance_config ⇒ Types::PerformanceConfiguration
Model performance configuration metadata for the conversation stream event.
-
#reasoning_content ⇒ Types::ReasoningContentBlockDelta
Contains content regarding the reasoning that is carried out by the model.
-
#reasoning_text ⇒ Types::ReasoningTextBlock
The reasoning that the model used to return the output.
-
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons.
-
#role ⇒ String
The role for the message.
-
#s3_location ⇒ Types::S3Location
The location of a video object in an Amazon S3 bucket.
-
#s3_output_data_config ⇒ Types::AsyncInvokeS3OutputDataConfig
A storage location for the output data in an S3 bucket.
-
#signature ⇒ String
A token that verifies that the reasoning text was generated by the model.
-
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
-
#stop_reason ⇒ String
The reason why the model stopped generating output.
-
#text ⇒ String
A tool result that is text.
-
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
-
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
-
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
-
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
-
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
-
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
-
#video ⇒ Types::VideoBlock
A tool result that is video.
Instance Attribute Details
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2827 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3396 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#auto ⇒ Types::AutoToolChoice
(Default). The Model automatically decides if a tool should be called or whether to generate text instead.
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3396 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#bytes ⇒ String
Video content encoded in base64.
237 238 239 240 241 242 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 237 class BidirectionalInputPayloadPart < Struct.new( :bytes, :event_type) SENSITIVE = [:bytes] include Aws::Structure end |
#cache_point ⇒ Types::CachePointBlock
CachePoint to include in the tool configuration.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#citation ⇒ Types::CitationsDelta
Incremental citation information that is streamed as part of the response generation process.
620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 620 class ContentBlockDelta < Struct.new( :text, :tool_use, :reasoning_content, :citation, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlockDelta; end class ToolUse < ContentBlockDelta; end class ReasoningContent < ContentBlockDelta; end class Citation < ContentBlockDelta; end class Unknown < ContentBlockDelta; end end |
#citations_content ⇒ Types::CitationsContentBlock
A content block that contains both generated text and associated citation information, providing traceability between the response and source documents.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#content ⇒ Array<Types::DocumentContentBlock>
The structured content of the document source, which may include various content blocks such as text, images, or other document elements.
1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1389 class DocumentSource < Struct.new( :bytes, :s3_location, :text, :content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class S3Location < DocumentSource; end class Text < DocumentSource; end class Content < DocumentSource; end class Unknown < DocumentSource; end end |
#content_block_index ⇒ Integer
The index for a content block.
649 650 651 652 653 654 655 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 649 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
649 650 651 652 653 654 655 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 649 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#document ⇒ Types::DocumentBlock
A tool result that is a document.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#document_char ⇒ Types::DocumentCharLocation
The character-level location within the document where the cited content is found.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 357 class CitationLocation < Struct.new( :document_char, :document_page, :document_chunk, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DocumentChar < CitationLocation; end class DocumentPage < CitationLocation; end class DocumentChunk < CitationLocation; end class Unknown < CitationLocation; end end |
#document_chunk ⇒ Types::DocumentChunkLocation
The chunk-level location within the document where the cited content is found, typically used for documents that have been segmented into logical chunks.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 357 class CitationLocation < Struct.new( :document_char, :document_page, :document_chunk, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DocumentChar < CitationLocation; end class DocumentPage < CitationLocation; end class DocumentChunk < CitationLocation; end class Unknown < CitationLocation; end end |
#document_page ⇒ Types::DocumentPageLocation
The page-level location within the document where the cited content is found.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 357 class CitationLocation < Struct.new( :document_char, :document_page, :document_chunk, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DocumentChar < CitationLocation; end class DocumentPage < CitationLocation; end class DocumentChunk < CitationLocation; end class Unknown < CitationLocation; end end |
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail. Use with the
- Converse][1
-
or [ConverseStream] API operations.
For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#image ⇒ Types::ImageBlock
A tool result that is an image.
<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.
</note>
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#json ⇒ Hash, ...
A tool result that is JSON format data.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3451 class ToolInputSchema < Struct.new( :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Json < ToolInputSchema; end class Unknown < ToolInputSchema; end end |
#message ⇒ String
745 746 747 748 749 750 751 752 753 754 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 745 class ConverseOutput < Struct.new( :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Message < ConverseOutput; end class Unknown < ConverseOutput; end end |
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
969 970 971 972 973 974 975 976 977 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 969 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_message ⇒ String
The original message.
2893 2894 2895 2896 2897 2898 2899 2900 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2893 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_status_code ⇒ Integer
The original status code.
2893 2894 2895 2896 2897 2898 2899 2900 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2893 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#performance_config ⇒ Types::PerformanceConfiguration
Model performance configuration metadata for the conversation stream event.
969 970 971 972 973 974 975 976 977 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 969 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#reasoning_content ⇒ Types::ReasoningContentBlockDelta
Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#reasoning_text ⇒ Types::ReasoningTextBlock
The reasoning that the model used to return the output.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3009 class ReasoningContentBlock < Struct.new( :reasoning_text, :redacted_content, :unknown) SENSITIVE = [:reasoning_text] include Aws::Structure include Aws::Structure::Union class ReasoningText < ReasoningContentBlock; end class RedactedContent < ReasoningContentBlock; end class Unknown < ReasoningContentBlock; end end |
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.
3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3009 class ReasoningContentBlock < Struct.new( :reasoning_text, :redacted_content, :unknown) SENSITIVE = [:reasoning_text] include Aws::Structure include Aws::Structure::Union class ReasoningText < ReasoningContentBlock; end class RedactedContent < ReasoningContentBlock; end class Unknown < ReasoningContentBlock; end end |
#role ⇒ String
The role for the message.
2808 2809 2810 2811 2812 2813 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2808 class MessageStartEvent < Struct.new( :role, :event_type) SENSITIVE = [] include Aws::Structure end |
#s3_location ⇒ Types::S3Location
The location of a video object in an Amazon S3 bucket. To see which models support S3 uploads, see [Supported models and features for Converse].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/conversation-inference-supported-models-features.html
1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1389 class DocumentSource < Struct.new( :bytes, :s3_location, :text, :content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class S3Location < DocumentSource; end class Text < DocumentSource; end class Content < DocumentSource; end class Unknown < DocumentSource; end end |
#s3_output_data_config ⇒ Types::AsyncInvokeS3OutputDataConfig
A storage location for the output data in an S3 bucket
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 129 class AsyncInvokeOutputDataConfig < Struct.new( :s3_output_data_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3OutputDataConfig < AsyncInvokeOutputDataConfig; end class Unknown < AsyncInvokeOutputDataConfig; end end |
#signature ⇒ String
A token that verifies that the reasoning text was generated by the model. If you pass a reasoning block back to the API in a multi-turn conversation, include the text and its signature unmodified.
3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3047 class ReasoningContentBlockDelta < Struct.new( :text, :redacted_content, :signature, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ReasoningContentBlockDelta; end class RedactedContent < ReasoningContentBlockDelta; end class Signature < ReasoningContentBlockDelta; end class Unknown < ReasoningContentBlockDelta; end end |
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
690 691 692 693 694 695 696 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 690 class ContentBlockStartEvent < Struct.new( :start, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#stop_reason ⇒ String
The reason why the model stopped generating output.
2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2827 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
A tool result that is text.
319 320 321 322 323 324 325 326 327 328 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 319 class CitationGeneratedContent < Struct.new( :text, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < CitationGeneratedContent; end class Unknown < CitationGeneratedContent; end end |
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool. Only supported by Anthropic Claude 3 models.
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3396 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3361 class Tool < Struct.new( :tool_spec, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ToolSpec < Tool; end class CachePoint < Tool; end class Unknown < Tool; end end |
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
969 970 971 972 973 974 975 976 977 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 969 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
969 970 971 972 973 974 975 976 977 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 969 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#video ⇒ Types::VideoBlock
A tool result that is video.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 566 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :cache_point, :reasoning_content, :citations_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class CachePoint < ContentBlock; end class ReasoningContent < ContentBlock; end class CitationsContent < ContentBlock; end class Unknown < ContentBlock; end end |