Module: Aws::BedrockRuntime::Types

Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AnyToolChoice, ApplyGuardrailRequest, ApplyGuardrailResponse, AsyncInvokeOutputDataConfig, AsyncInvokeS3OutputDataConfig, AsyncInvokeSummary, AutoToolChoice, CachePointBlock, ConflictException, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTrace, DocumentBlock, DocumentSource, GetAsyncInvokeRequest, GetAsyncInvokeResponse, GuardrailAssessment, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseImageBlock, GuardrailConverseImageSource, GuardrailConverseTextBlock, GuardrailCoverage, GuardrailCustomWord, GuardrailImageBlock, GuardrailImageCoverage, GuardrailImageSource, GuardrailInvocationMetrics, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTextCharactersCoverage, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, ListAsyncInvokesRequest, ListAsyncInvokesResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, PerformanceConfiguration, PromptRouterTrace, PromptVariableValues, ReasoningContentBlock, ReasoningContentBlockDelta, ReasoningTextBlock, ResourceNotFoundException, ResponseStream, S3Location, ServiceQuotaExceededException, ServiceUnavailableException, SpecificToolChoice, StartAsyncInvokeRequest, StartAsyncInvokeResponse, SystemContentBlock, Tag, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException, VideoBlock, VideoSource

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_response_fieldsHash, ...

The additional model response fields.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2368
2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2368

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#anyTypes::AnyToolChoice

The model must request at least one tool (no text is generated).



2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2937

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#autoTypes::AutoToolChoice

(Default). The Model automatically decides if a tool should be called or whether to generate text instead.



2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2937

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#bytesString

Video content encoded in base64.

Returns:

  • (String)


991
992
993
994
995
996
997
998
999
1000
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 991

class DocumentSource < Struct.new(
  :bytes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < DocumentSource; end
  class Unknown < DocumentSource; end
end

#cache_pointTypes::CachePointBlock

CachePoint to include in the tool configuration.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#content_block_indexInteger

The index for a content block.

Returns:

  • (Integer)


391
392
393
394
395
396
397
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 391

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#deltaTypes::ContentBlockDelta

The delta for a content block delta event.



391
392
393
394
395
396
397
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 391

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#documentTypes::DocumentBlock

A tool result that is a document.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#guard_contentTypes::GuardrailConverseContentBlock

A content block to assess with the guardrail. Use with the

Converse][1

or [ConverseStream] API operations.

For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#imageTypes::ImageBlock

A tool result that is an image.

<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.

</note>

Returns:



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#jsonHash, ...

A tool result that is JSON format data.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2992

class ToolInputSchema < Struct.new(
  :json,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Json < ToolInputSchema; end
  class Unknown < ToolInputSchema; end
end

#messageString

Returns:

  • (String)


487
488
489
490
491
492
493
494
495
496
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 487

class ConverseOutput < Struct.new(
  :message,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Message < ConverseOutput; end
  class Unknown < ConverseOutput; end
end

#metricsTypes::ConverseStreamMetrics

The metrics for the conversation stream metadata event.



711
712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 711

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#original_messageString

The original message.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2434

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#original_status_codeInteger

The original status code.

Returns:

  • (Integer)


2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2434

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#performance_configTypes::PerformanceConfiguration

Model performance configuration metadata for the conversation stream event.



711
712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 711

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#reasoning_contentTypes::ReasoningContentBlockDelta

Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#reasoning_textTypes::ReasoningTextBlock

The reasoning that the model used to return the output.



2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2550

class ReasoningContentBlock < Struct.new(
  :reasoning_text,
  :redacted_content,
  :unknown)
  SENSITIVE = [:reasoning_text]
  include Aws::Structure
  include Aws::Structure::Union

  class ReasoningText < ReasoningContentBlock; end
  class RedactedContent < ReasoningContentBlock; end
  class Unknown < ReasoningContentBlock; end
end

#redacted_contentString

The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.

Returns:

  • (String)


2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2550

class ReasoningContentBlock < Struct.new(
  :reasoning_text,
  :redacted_content,
  :unknown)
  SENSITIVE = [:reasoning_text]
  include Aws::Structure
  include Aws::Structure::Union

  class ReasoningText < ReasoningContentBlock; end
  class RedactedContent < ReasoningContentBlock; end
  class Unknown < ReasoningContentBlock; end
end

#roleString

The role for the message.

Returns:

  • (String)


2349
2350
2351
2352
2353
2354
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2349

class MessageStartEvent < Struct.new(
  :role,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationTypes::S3Location

The location of a video object in an S3 bucket.

Returns:



3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3223

class VideoSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < VideoSource; end
  class S3Location < VideoSource; end
  class Unknown < VideoSource; end
end

#s3_output_data_configTypes::AsyncInvokeS3OutputDataConfig

A storage location for the output data in an S3 bucket



129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 129

class AsyncInvokeOutputDataConfig < Struct.new(
  :s3_output_data_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3OutputDataConfig < AsyncInvokeOutputDataConfig; end
  class Unknown < AsyncInvokeOutputDataConfig; end
end

#signatureString

A token that verifies that the reasoning text was generated by the model. If you pass a reasoning block back to the API in a multi-turn conversation, include the text and its signature unmodified.

Returns:

  • (String)


2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2588

class ReasoningContentBlockDelta < Struct.new(
  :text,
  :redacted_content,
  :signature,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ReasoningContentBlockDelta; end
  class RedactedContent < ReasoningContentBlockDelta; end
  class Signature < ReasoningContentBlockDelta; end
  class Unknown < ReasoningContentBlockDelta; end
end

#startTypes::ContentBlockStart

Start information about a content block start event.



432
433
434
435
436
437
438
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 432

class ContentBlockStartEvent < Struct.new(
  :start,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#stop_reasonString

The reason why the model stopped generating output.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2368

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#textString

A tool result that is text.

Returns:

  • (String)


317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#toolTypes::SpecificToolChoice

The Model must request the specified tool. Only supported by Anthropic Claude 3 models.



2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2937

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#tool_resultTypes::ToolResultBlock

The result for a tool request that a model makes.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#tool_specTypes::ToolSpecification

The specfication for the tool.



2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2902

class Tool < Struct.new(
  :tool_spec,
  :cache_point,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ToolSpec < Tool; end
  class CachePoint < Tool; end
  class Unknown < Tool; end
end

#tool_useTypes::ToolUseBlockStart

Information about a tool that the model is requesting to use.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#traceTypes::ConverseStreamTrace

The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



711
712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 711

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#usageTypes::TokenUsage

Usage information for the conversation stream event.

Returns:



711
712
713
714
715
716
717
718
719
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 711

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#videoTypes::VideoBlock

A tool result that is video.

Returns:



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 317

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :cache_point,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class CachePoint < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end