Module: Aws::BedrockRuntime::Types

Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AnyToolChoice, ApplyGuardrailRequest, ApplyGuardrailResponse, AsyncInvokeOutputDataConfig, AsyncInvokeS3OutputDataConfig, AsyncInvokeSummary, AutoToolChoice, ConflictException, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTrace, DocumentBlock, DocumentSource, GetAsyncInvokeRequest, GetAsyncInvokeResponse, GuardrailAssessment, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseImageBlock, GuardrailConverseImageSource, GuardrailConverseTextBlock, GuardrailCoverage, GuardrailCustomWord, GuardrailImageBlock, GuardrailImageCoverage, GuardrailImageSource, GuardrailInvocationMetrics, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTextCharactersCoverage, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, ListAsyncInvokesRequest, ListAsyncInvokesResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, PerformanceConfiguration, PromptRouterTrace, PromptVariableValues, ReasoningContentBlock, ReasoningContentBlockDelta, ReasoningTextBlock, ResourceNotFoundException, ResponseStream, S3Location, ServiceQuotaExceededException, ServiceUnavailableException, SpecificToolChoice, StartAsyncInvokeRequest, StartAsyncInvokeResponse, SystemContentBlock, Tag, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException, VideoBlock, VideoSource

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_response_fieldsHash, ...

The additional model response fields.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2276
2277
2278
2279
2280
2281
2282
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2276

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#anyTypes::AnyToolChoice

The model must request at least one tool (no text is generated).



2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2823

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#autoTypes::AutoToolChoice

(Default). The Model automatically decides if a tool should be called or whether to generate text instead.



2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2823

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#bytesString

Video content encoded in base64.

Returns:

  • (String)


953
954
955
956
957
958
959
960
961
962
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 953

class DocumentSource < Struct.new(
  :bytes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < DocumentSource; end
  class Unknown < DocumentSource; end
end

#content_block_indexInteger

The index for a content block.

Returns:

  • (Integer)


353
354
355
356
357
358
359
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 353

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#deltaTypes::ContentBlockDelta

The delta for a content block delta event.



353
354
355
356
357
358
359
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 353

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#documentTypes::DocumentBlock

A tool result that is a document.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#guard_contentTypes::GuardrailConverseContentBlock

A content block to assess with the guardrail. Use with the

Converse][1

or [ConverseStream] API operations.

For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#imageTypes::ImageBlock

A tool result that is an image.

<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.

</note>

Returns:



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#jsonHash, ...

A tool result that is JSON format data.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2878

class ToolInputSchema < Struct.new(
  :json,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Json < ToolInputSchema; end
  class Unknown < ToolInputSchema; end
end

#messageString

Returns:

  • (String)


449
450
451
452
453
454
455
456
457
458
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 449

class ConverseOutput < Struct.new(
  :message,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Message < ConverseOutput; end
  class Unknown < ConverseOutput; end
end

#metricsTypes::ConverseStreamMetrics

The metrics for the conversation stream metadata event.



673
674
675
676
677
678
679
680
681
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#original_messageString

The original message.

Returns:

  • (String)


2342
2343
2344
2345
2346
2347
2348
2349
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2342

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#original_status_codeInteger

The original status code.

Returns:

  • (Integer)


2342
2343
2344
2345
2346
2347
2348
2349
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2342

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#performance_configTypes::PerformanceConfiguration

Model performance configuration metadata for the conversation stream event.



673
674
675
676
677
678
679
680
681
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#reasoning_contentTypes::ReasoningContentBlockDelta

Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#reasoning_textTypes::ReasoningTextBlock

The reasoning that the model used to return the output.



2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2458

class ReasoningContentBlock < Struct.new(
  :reasoning_text,
  :redacted_content,
  :unknown)
  SENSITIVE = [:reasoning_text]
  include Aws::Structure
  include Aws::Structure::Union

  class ReasoningText < ReasoningContentBlock; end
  class RedactedContent < ReasoningContentBlock; end
  class Unknown < ReasoningContentBlock; end
end

#redacted_contentString

The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.

Returns:

  • (String)


2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2458

class ReasoningContentBlock < Struct.new(
  :reasoning_text,
  :redacted_content,
  :unknown)
  SENSITIVE = [:reasoning_text]
  include Aws::Structure
  include Aws::Structure::Union

  class ReasoningText < ReasoningContentBlock; end
  class RedactedContent < ReasoningContentBlock; end
  class Unknown < ReasoningContentBlock; end
end

#roleString

The role for the message.

Returns:

  • (String)


2257
2258
2259
2260
2261
2262
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2257

class MessageStartEvent < Struct.new(
  :role,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationTypes::S3Location

The location of a video object in an S3 bucket.

Returns:



3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3109

class VideoSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < VideoSource; end
  class S3Location < VideoSource; end
  class Unknown < VideoSource; end
end

#s3_output_data_configTypes::AsyncInvokeS3OutputDataConfig

A storage location for the output data in an S3 bucket



112
113
114
115
116
117
118
119
120
121
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 112

class AsyncInvokeOutputDataConfig < Struct.new(
  :s3_output_data_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3OutputDataConfig < AsyncInvokeOutputDataConfig; end
  class Unknown < AsyncInvokeOutputDataConfig; end
end

#signatureString

A token that verifies that the reasoning text was generated by the model. If you pass a reasoning block back to the API in a multi-turn conversation, include the text and its signature unmodified.

Returns:

  • (String)


2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2496

class ReasoningContentBlockDelta < Struct.new(
  :text,
  :redacted_content,
  :signature,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ReasoningContentBlockDelta; end
  class RedactedContent < ReasoningContentBlockDelta; end
  class Signature < ReasoningContentBlockDelta; end
  class Unknown < ReasoningContentBlockDelta; end
end

#startTypes::ContentBlockStart

Start information about a content block start event.



394
395
396
397
398
399
400
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 394

class ContentBlockStartEvent < Struct.new(
  :start,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#stop_reasonString

The reason why the model stopped generating output.

Returns:

  • (String)


2276
2277
2278
2279
2280
2281
2282
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2276

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#textString

A tool result that is text.

Returns:

  • (String)


281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#toolTypes::SpecificToolChoice

The Model must request the specified tool. Only supported by Anthropic Claude 3 models.



2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2823

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#tool_resultTypes::ToolResultBlock

The result for a tool request that a model makes.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#tool_specTypes::ToolSpecification

The specfication for the tool.



2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2790

class Tool < Struct.new(
  :tool_spec,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ToolSpec < Tool; end
  class Unknown < Tool; end
end

#tool_useTypes::ToolUseBlockStart

Information about a tool that the model is requesting to use.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#traceTypes::ConverseStreamTrace

The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



673
674
675
676
677
678
679
680
681
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#usageTypes::TokenUsage

Usage information for the conversation stream event.

Returns:



673
674
675
676
677
678
679
680
681
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :performance_config,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#videoTypes::VideoBlock

A tool result that is video.

Returns:



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :video,
  :tool_use,
  :tool_result,
  :guard_content,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class Video < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class ReasoningContent < ContentBlock; end
  class Unknown < ContentBlock; end
end