Module: Aws::BedrockRuntime::Types
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AnyToolChoice, ApplyGuardrailRequest, ApplyGuardrailResponse, AsyncInvokeOutputDataConfig, AsyncInvokeS3OutputDataConfig, AsyncInvokeSummary, AutoToolChoice, ConflictException, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTrace, DocumentBlock, DocumentSource, GetAsyncInvokeRequest, GetAsyncInvokeResponse, GuardrailAssessment, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseImageBlock, GuardrailConverseImageSource, GuardrailConverseTextBlock, GuardrailCoverage, GuardrailCustomWord, GuardrailImageBlock, GuardrailImageCoverage, GuardrailImageSource, GuardrailInvocationMetrics, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTextCharactersCoverage, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, ListAsyncInvokesRequest, ListAsyncInvokesResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, PerformanceConfiguration, PromptRouterTrace, PromptVariableValues, ReasoningContentBlock, ReasoningContentBlockDelta, ReasoningTextBlock, ResourceNotFoundException, ResponseStream, S3Location, ServiceQuotaExceededException, ServiceUnavailableException, SpecificToolChoice, StartAsyncInvokeRequest, StartAsyncInvokeResponse, SystemContentBlock, Tag, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException, VideoBlock, VideoSource
Instance Attribute Summary collapse
-
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
-
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
-
#auto ⇒ Types::AutoToolChoice
(Default).
-
#bytes ⇒ String
Video content encoded in base64.
-
#content_block_index ⇒ Integer
The index for a content block.
-
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
-
#document ⇒ Types::DocumentBlock
A tool result that is a document.
-
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail.
-
#image ⇒ Types::ImageBlock
A tool result that is an image.
-
#json ⇒ Hash, ...
A tool result that is JSON format data.
- #message ⇒ String
-
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
-
#original_message ⇒ String
The original message.
-
#original_status_code ⇒ Integer
The original status code.
-
#performance_config ⇒ Types::PerformanceConfiguration
Model performance configuration metadata for the conversation stream event.
-
#reasoning_content ⇒ Types::ReasoningContentBlockDelta
Contains content regarding the reasoning that is carried out by the model.
-
#reasoning_text ⇒ Types::ReasoningTextBlock
The reasoning that the model used to return the output.
-
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons.
-
#role ⇒ String
The role for the message.
-
#s3_location ⇒ Types::S3Location
The location of a video object in an S3 bucket.
-
#s3_output_data_config ⇒ Types::AsyncInvokeS3OutputDataConfig
A storage location for the output data in an S3 bucket.
-
#signature ⇒ String
A token that verifies that the reasoning text was generated by the model.
-
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
-
#stop_reason ⇒ String
The reason why the model stopped generating output.
-
#text ⇒ String
A tool result that is text.
-
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
-
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
-
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
-
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
-
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
-
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
-
#video ⇒ Types::VideoBlock
A tool result that is video.
Instance Attribute Details
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
2276 2277 2278 2279 2280 2281 2282 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2276 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2823 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#auto ⇒ Types::AutoToolChoice
(Default). The Model automatically decides if a tool should be called or whether to generate text instead.
2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2823 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#bytes ⇒ String
Video content encoded in base64.
953 954 955 956 957 958 959 960 961 962 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 953 class DocumentSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class Unknown < DocumentSource; end end |
#content_block_index ⇒ Integer
The index for a content block.
353 354 355 356 357 358 359 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 353 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
353 354 355 356 357 358 359 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 353 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#document ⇒ Types::DocumentBlock
A tool result that is a document.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail. Use with the
- Converse][1
-
or [ConverseStream] API operations.
For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |
#image ⇒ Types::ImageBlock
A tool result that is an image.
<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.
</note>
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |
#json ⇒ Hash, ...
A tool result that is JSON format data.
2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2878 class ToolInputSchema < Struct.new( :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Json < ToolInputSchema; end class Unknown < ToolInputSchema; end end |
#message ⇒ String
449 450 451 452 453 454 455 456 457 458 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 449 class ConverseOutput < Struct.new( :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Message < ConverseOutput; end class Unknown < ConverseOutput; end end |
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
673 674 675 676 677 678 679 680 681 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_message ⇒ String
The original message.
2342 2343 2344 2345 2346 2347 2348 2349 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2342 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_status_code ⇒ Integer
The original status code.
2342 2343 2344 2345 2346 2347 2348 2349 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2342 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#performance_config ⇒ Types::PerformanceConfiguration
Model performance configuration metadata for the conversation stream event.
673 674 675 676 677 678 679 680 681 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#reasoning_content ⇒ Types::ReasoningContentBlockDelta
Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |
#reasoning_text ⇒ Types::ReasoningTextBlock
The reasoning that the model used to return the output.
2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2458 class ReasoningContentBlock < Struct.new( :reasoning_text, :redacted_content, :unknown) SENSITIVE = [:reasoning_text] include Aws::Structure include Aws::Structure::Union class ReasoningText < ReasoningContentBlock; end class RedactedContent < ReasoningContentBlock; end class Unknown < ReasoningContentBlock; end end |
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.
2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2458 class ReasoningContentBlock < Struct.new( :reasoning_text, :redacted_content, :unknown) SENSITIVE = [:reasoning_text] include Aws::Structure include Aws::Structure::Union class ReasoningText < ReasoningContentBlock; end class RedactedContent < ReasoningContentBlock; end class Unknown < ReasoningContentBlock; end end |
#role ⇒ String
The role for the message.
2257 2258 2259 2260 2261 2262 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2257 class MessageStartEvent < Struct.new( :role, :event_type) SENSITIVE = [] include Aws::Structure end |
#s3_location ⇒ Types::S3Location
The location of a video object in an S3 bucket.
3109 3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3109 class VideoSource < Struct.new( :bytes, :s3_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < VideoSource; end class S3Location < VideoSource; end class Unknown < VideoSource; end end |
#s3_output_data_config ⇒ Types::AsyncInvokeS3OutputDataConfig
A storage location for the output data in an S3 bucket
112 113 114 115 116 117 118 119 120 121 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 112 class AsyncInvokeOutputDataConfig < Struct.new( :s3_output_data_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3OutputDataConfig < AsyncInvokeOutputDataConfig; end class Unknown < AsyncInvokeOutputDataConfig; end end |
#signature ⇒ String
A token that verifies that the reasoning text was generated by the model. If you pass a reasoning block back to the API in a multi-turn conversation, include the text and its signature unmodified.
2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2496 class ReasoningContentBlockDelta < Struct.new( :text, :redacted_content, :signature, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ReasoningContentBlockDelta; end class RedactedContent < ReasoningContentBlockDelta; end class Signature < ReasoningContentBlockDelta; end class Unknown < ReasoningContentBlockDelta; end end |
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 394 class ContentBlockStartEvent < Struct.new( :start, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#stop_reason ⇒ String
The reason why the model stopped generating output.
2276 2277 2278 2279 2280 2281 2282 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2276 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
A tool result that is text.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool. Only supported by Anthropic Claude 3 models.
2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2823 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2790 class Tool < Struct.new( :tool_spec, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ToolSpec < Tool; end class Unknown < Tool; end end |
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
673 674 675 676 677 678 679 680 681 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
673 674 675 676 677 678 679 680 681 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 673 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#video ⇒ Types::VideoBlock
A tool result that is video.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 281 class ContentBlock < Struct.new( :text, :image, :document, :video, :tool_use, :tool_result, :guard_content, :reasoning_content, :unknown) SENSITIVE = [:reasoning_content] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class Video < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class ReasoningContent < ContentBlock; end class Unknown < ContentBlock; end end |