Module: Aws::BedrockRuntime::Types
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AnyToolChoice, ApplyGuardrailRequest, ApplyGuardrailResponse, AutoToolChoice, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTrace, DocumentBlock, DocumentSource, GuardrailAssessment, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseTextBlock, GuardrailCoverage, GuardrailCustomWord, GuardrailInvocationMetrics, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTextCharactersCoverage, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, PerformanceConfiguration, PromptVariableValues, ResourceNotFoundException, ResponseStream, ServiceQuotaExceededException, ServiceUnavailableException, SpecificToolChoice, SystemContentBlock, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException
Instance Attribute Summary collapse
-
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
-
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
-
#auto ⇒ Types::AutoToolChoice
(Default).
-
#bytes ⇒ String
Base64-encoded bytes of payload data.
-
#content_block_index ⇒ Integer
The index for a content block.
-
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
-
#document ⇒ Types::DocumentBlock
A tool result that is a document.
-
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail.
-
#image ⇒ Types::ImageBlock
A tool result that is an image.
-
#json ⇒ Hash, ...
A tool result that is JSON format data.
- #message ⇒ String
-
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
-
#original_message ⇒ String
The original message.
-
#original_status_code ⇒ Integer
The original status code.
-
#performance_config ⇒ Types::PerformanceConfiguration
Model performance configuration metadata for the conversation stream event.
-
#role ⇒ String
The role for the message.
-
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
-
#stop_reason ⇒ String
The reason why the model stopped generating output.
-
#text ⇒ String
A tool result that is text.
-
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
-
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
-
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
-
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
-
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
-
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
Instance Attribute Details
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
1859 1860 1861 1862 1863 1864 1865 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1859 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2210 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#auto ⇒ Types::AutoToolChoice
(Default). The Model automatically decides if a tool should be called or whether to generate text instead.
2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2210 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#bytes ⇒ String
Base64-encoded bytes of payload data.
791 792 793 794 795 796 797 798 799 800 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 791 class DocumentSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class Unknown < DocumentSource; end end |
#content_block_index ⇒ Integer
The index for a content block.
216 217 218 219 220 221 222 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 216 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
216 217 218 219 220 221 222 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 216 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#document ⇒ Types::DocumentBlock
A tool result that is a document.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 156 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail. Use with the
- Converse][1
-
or [ConverseStream] API operations.
For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 156 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#image ⇒ Types::ImageBlock
A tool result that is an image.
<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.
</note>
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 156 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#json ⇒ Hash, ...
A tool result that is JSON format data.
2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2270 class ToolInputSchema < Struct.new( :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Json < ToolInputSchema; end class Unknown < ToolInputSchema; end end |
#message ⇒ String
312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 312 class ConverseOutput < Struct.new( :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Message < ConverseOutput; end class Unknown < ConverseOutput; end end |
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
529 530 531 532 533 534 535 536 537 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 529 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_message ⇒ String
The original message.
1925 1926 1927 1928 1929 1930 1931 1932 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1925 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_status_code ⇒ Integer
The original status code.
1925 1926 1927 1928 1929 1930 1931 1932 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1925 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#performance_config ⇒ Types::PerformanceConfiguration
Model performance configuration metadata for the conversation stream event.
529 530 531 532 533 534 535 536 537 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 529 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role for the message.
1840 1841 1842 1843 1844 1845 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1840 class MessageStartEvent < Struct.new( :role, :event_type) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
257 258 259 260 261 262 263 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 257 class ContentBlockStartEvent < Struct.new( :start, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#stop_reason ⇒ String
The reason why the model stopped generating output.
1859 1860 1861 1862 1863 1864 1865 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1859 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
A tool result that is text.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 156 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool. Only supported by Anthropic Claude 3 models.
2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2210 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 156 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2177 class Tool < Struct.new( :tool_spec, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ToolSpec < Tool; end class Unknown < Tool; end end |
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 156 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
529 530 531 532 533 534 535 536 537 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 529 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
529 530 531 532 533 534 535 536 537 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 529 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :performance_config, :event_type) SENSITIVE = [] include Aws::Structure end |