Module: Aws::BedrockRuntime::Types

Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AnyToolChoice, ApplyGuardrailRequest, ApplyGuardrailResponse, AutoToolChoice, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTrace, DocumentBlock, DocumentSource, GuardrailAssessment, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseTextBlock, GuardrailCustomWord, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, ResourceNotFoundException, ResponseStream, ServiceQuotaExceededException, ServiceUnavailableException, SpecificToolChoice, SystemContentBlock, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_response_fieldsHash, ...

The additional model response fields.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


1680
1681
1682
1683
1684
1685
1686
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1680

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#anyTypes::AnyToolChoice

The model must request at least one tool (no text is generated).



1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1981

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#autoTypes::AutoToolChoice

(Default). The Model automatically decides if a tool should be called or whether to generate text instead.



1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1981

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#bytesString

Base64-encoded bytes of payload data.

Returns:

  • (String)


718
719
720
721
722
723
724
725
726
727
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 718

class DocumentSource < Struct.new(
  :bytes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < DocumentSource; end
  class Unknown < DocumentSource; end
end

#content_block_indexInteger

The index for a content block.

Returns:

  • (Integer)


205
206
207
208
209
210
211
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 205

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#deltaTypes::ContentBlockDelta

The delta for a content block delta event.



205
206
207
208
209
210
211
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 205

class ContentBlockDeltaEvent < Struct.new(
  :delta,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#documentTypes::DocumentBlock

A tool result that is a document.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :tool_use,
  :tool_result,
  :guard_content,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#guard_contentTypes::GuardrailConverseContentBlock

A content block to assess with the guardrail. Use with the

Converse][1

or [ConverseStream] API operations.

For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :tool_use,
  :tool_result,
  :guard_content,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#imageTypes::ImageBlock

A tool result that is an image.

<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.

</note>

Returns:



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :tool_use,
  :tool_result,
  :guard_content,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#jsonHash, ...

A tool result that is JSON format data.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2041

class ToolInputSchema < Struct.new(
  :json,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Json < ToolInputSchema; end
  class Unknown < ToolInputSchema; end
end

#messageString

Returns:

  • (String)


301
302
303
304
305
306
307
308
309
310
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 301

class ConverseOutput < Struct.new(
  :message,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Message < ConverseOutput; end
  class Unknown < ConverseOutput; end
end

#metricsTypes::ConverseStreamMetrics

The metrics for the conversation stream metadata event.



485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 485

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#original_messageString

The original message.

Returns:

  • (String)


1746
1747
1748
1749
1750
1751
1752
1753
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1746

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#original_status_codeInteger

The original status code.

Returns:

  • (Integer)


1746
1747
1748
1749
1750
1751
1752
1753
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1746

class ModelStreamErrorException < Struct.new(
  :message,
  :original_status_code,
  :original_message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The role for the message.

Returns:

  • (String)


1661
1662
1663
1664
1665
1666
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1661

class MessageStartEvent < Struct.new(
  :role,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#startTypes::ContentBlockStart

Start information about a content block start event.



246
247
248
249
250
251
252
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 246

class ContentBlockStartEvent < Struct.new(
  :start,
  :content_block_index,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#stop_reasonString

The reason why the model stopped generating output.

Returns:

  • (String)


1680
1681
1682
1683
1684
1685
1686
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1680

class MessageStopEvent < Struct.new(
  :stop_reason,
  :additional_model_response_fields,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#textString

A tool result that is text.

Returns:

  • (String)


145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :tool_use,
  :tool_result,
  :guard_content,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#toolTypes::SpecificToolChoice

The Model must request the specified tool. Only supported by Anthropic Claude 3 models.



1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1981

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#tool_resultTypes::ToolResultBlock

The result for a tool request that a model makes.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :tool_use,
  :tool_result,
  :guard_content,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#tool_specTypes::ToolSpecification

The specfication for the tool.



1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1948

class Tool < Struct.new(
  :tool_spec,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ToolSpec < Tool; end
  class Unknown < Tool; end
end

#tool_useTypes::ToolUseBlockStart

Information about a tool that the model is requesting to use.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145

class ContentBlock < Struct.new(
  :text,
  :image,
  :document,
  :tool_use,
  :tool_result,
  :guard_content,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlock; end
  class Image < ContentBlock; end
  class Document < ContentBlock; end
  class ToolUse < ContentBlock; end
  class ToolResult < ContentBlock; end
  class GuardContent < ContentBlock; end
  class Unknown < ContentBlock; end
end

#traceTypes::ConverseStreamTrace

The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html



485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 485

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#usageTypes::TokenUsage

Usage information for the conversation stream event.

Returns:



485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 485

class ConverseStreamMetadataEvent < Struct.new(
  :usage,
  :metrics,
  :trace,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end