Module: Aws::BedrockRuntime::Types
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AnyToolChoice, ApplyGuardrailRequest, ApplyGuardrailResponse, AutoToolChoice, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ConverseStreamTrace, ConverseTrace, DocumentBlock, DocumentSource, GuardrailAssessment, GuardrailConfiguration, GuardrailContentBlock, GuardrailContentFilter, GuardrailContentPolicyAssessment, GuardrailContextualGroundingFilter, GuardrailContextualGroundingPolicyAssessment, GuardrailConverseContentBlock, GuardrailConverseTextBlock, GuardrailCustomWord, GuardrailManagedWord, GuardrailOutputContent, GuardrailPiiEntityFilter, GuardrailRegexFilter, GuardrailSensitiveInformationPolicyAssessment, GuardrailStreamConfiguration, GuardrailTextBlock, GuardrailTopic, GuardrailTopicPolicyAssessment, GuardrailTraceAssessment, GuardrailUsage, GuardrailWordPolicyAssessment, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, ResourceNotFoundException, ResponseStream, ServiceQuotaExceededException, ServiceUnavailableException, SpecificToolChoice, SystemContentBlock, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException
Instance Attribute Summary collapse
-
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
-
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
-
#auto ⇒ Types::AutoToolChoice
(Default).
-
#bytes ⇒ String
Base64-encoded bytes of payload data.
-
#content_block_index ⇒ Integer
The index for a content block.
-
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
-
#document ⇒ Types::DocumentBlock
A tool result that is a document.
-
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail.
-
#image ⇒ Types::ImageBlock
A tool result that is an image.
-
#json ⇒ Hash, ...
A tool result that is JSON format data.
- #message ⇒ String
-
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
-
#original_message ⇒ String
The original message.
-
#original_status_code ⇒ Integer
The original status code.
-
#role ⇒ String
The role for the message.
-
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
-
#stop_reason ⇒ String
The reason why the model stopped generating output.
-
#text ⇒ String
A tool result that is text.
-
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
-
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
-
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
-
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
-
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
-
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
Instance Attribute Details
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
1646 1647 1648 1649 1650 1651 1652 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1646 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1941 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#auto ⇒ Types::AutoToolChoice
(Default). The Model automatically decides if a tool should be called or whether to generate text instead.
1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1941 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#bytes ⇒ String
Base64-encoded bytes of payload data.
698 699 700 701 702 703 704 705 706 707 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 698 class DocumentSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class Unknown < DocumentSource; end end |
#content_block_index ⇒ Integer
The index for a content block.
205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 205 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 205 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#document ⇒ Types::DocumentBlock
A tool result that is a document.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail. Use with the
- Converse][1
-
or [ConverseStream] API operations.
For more information, see *Use a guardrail with the Converse API* in the *Amazon Bedrock User Guide*.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#image ⇒ Types::ImageBlock
A tool result that is an image.
<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.
</note>
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#json ⇒ Hash, ...
A tool result that is JSON format data.
2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2001 class ToolInputSchema < Struct.new( :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Json < ToolInputSchema; end class Unknown < ToolInputSchema; end end |
#message ⇒ String
301 302 303 304 305 306 307 308 309 310 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 301 class ConverseOutput < Struct.new( :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Message < ConverseOutput; end class Unknown < ConverseOutput; end end |
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
475 476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 475 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_message ⇒ String
The original message.
1706 1707 1708 1709 1710 1711 1712 1713 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1706 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_status_code ⇒ Integer
The original status code.
1706 1707 1708 1709 1710 1711 1712 1713 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1706 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role for the message.
1627 1628 1629 1630 1631 1632 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1627 class MessageStartEvent < Struct.new( :role, :event_type) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
246 247 248 249 250 251 252 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 246 class ContentBlockStartEvent < Struct.new( :start, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#stop_reason ⇒ String
The reason why the model stopped generating output.
1646 1647 1648 1649 1650 1651 1652 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1646 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
A tool result that is text.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool. Only supported by Anthropic Claude 3 models.
1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1941 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1908 class Tool < Struct.new( :tool_spec, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ToolSpec < Tool; end class Unknown < Tool; end end |
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 145 class ContentBlock < Struct.new( :text, :image, :document, :tool_use, :tool_result, :guard_content, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class Document < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class GuardContent < ContentBlock; end class Unknown < ContentBlock; end end |
#trace ⇒ Types::ConverseStreamTrace
The trace object in the response from [ConverseStream] that contains information about the guardrail behavior.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
475 476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 475 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :event_type) SENSITIVE = [] include Aws::Structure end |
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
475 476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 475 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :trace, :event_type) SENSITIVE = [] include Aws::Structure end |