Module: Aws::BedrockRuntime::Types
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AnyToolChoice, AutoToolChoice, ContentBlock, ContentBlockDelta, ContentBlockDeltaEvent, ContentBlockStart, ContentBlockStartEvent, ContentBlockStopEvent, ConverseMetrics, ConverseOutput, ConverseRequest, ConverseResponse, ConverseStreamMetadataEvent, ConverseStreamMetrics, ConverseStreamOutput, ConverseStreamRequest, ConverseStreamResponse, ImageBlock, ImageSource, InferenceConfiguration, InternalServerException, InvokeModelRequest, InvokeModelResponse, InvokeModelWithResponseStreamRequest, InvokeModelWithResponseStreamResponse, Message, MessageStartEvent, MessageStopEvent, ModelErrorException, ModelNotReadyException, ModelStreamErrorException, ModelTimeoutException, PayloadPart, ResourceNotFoundException, ResponseStream, ServiceQuotaExceededException, SpecificToolChoice, SystemContentBlock, ThrottlingException, TokenUsage, Tool, ToolChoice, ToolConfiguration, ToolInputSchema, ToolResultBlock, ToolResultContentBlock, ToolSpecification, ToolUseBlock, ToolUseBlockDelta, ToolUseBlockStart, ValidationException
Instance Attribute Summary collapse
-
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
-
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
-
#auto ⇒ Types::AutoToolChoice
The Model automatically decides if a tool should be called or to whether to generate text instead.
-
#bytes ⇒ String
Base64-encoded bytes of payload data.
-
#content_block_index ⇒ Integer
The index for a content block.
-
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
-
#image ⇒ Types::ImageBlock
A tool result that is an image.
-
#json ⇒ Hash, ...
A tool result that is JSON format data.
- #message ⇒ String
-
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
-
#original_message ⇒ String
The original message.
-
#original_status_code ⇒ Integer
The original status code.
-
#role ⇒ String
The role for the message.
-
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
-
#stop_reason ⇒ String
The reason why the model stopped generating output.
-
#text ⇒ String
A tool result that is text.
-
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
-
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
-
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
-
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
-
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
Instance Attribute Details
#additional_model_response_fields ⇒ Hash, ...
The additional model response fields.
920 921 922 923 924 925 926 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 920 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#any ⇒ Types::AnyToolChoice
The model must request at least one tool (no text is generated).
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1164 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#auto ⇒ Types::AutoToolChoice
The Model automatically decides if a tool should be called or to whether to generate text instead.
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1164 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#bytes ⇒ String
Base64-encoded bytes of payload data.
532 533 534 535 536 537 538 539 540 541 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 532 class ImageSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageSource; end class Unknown < ImageSource; end end |
#content_block_index ⇒ Integer
The index for a content block.
127 128 129 130 131 132 133 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 127 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#delta ⇒ Types::ContentBlockDelta
The delta for a content block delta event.
127 128 129 130 131 132 133 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 127 class ContentBlockDeltaEvent < Struct.new( :delta, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#image ⇒ Types::ImageBlock
A tool result that is an image.
<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.
</note>
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#json ⇒ Hash, ...
A tool result that is JSON format data.
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1218 class ToolInputSchema < Struct.new( :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Json < ToolInputSchema; end class Unknown < ToolInputSchema; end end |
#message ⇒ String
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 223 class ConverseOutput < Struct.new( :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Message < ConverseOutput; end class Unknown < ConverseOutput; end end |
#metrics ⇒ Types::ConverseStreamMetrics
The metrics for the conversation stream metadata event.
376 377 378 379 380 381 382 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 376 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_message ⇒ String
The original message.
980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 980 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#original_status_code ⇒ Integer
The original status code.
980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 980 class ModelStreamErrorException < Struct.new( :message, :original_status_code, :original_message, :event_type) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role for the message.
901 902 903 904 905 906 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 901 class MessageStartEvent < Struct.new( :role, :event_type) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Types::ContentBlockStart
Start information about a content block start event.
168 169 170 171 172 173 174 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 168 class ContentBlockStartEvent < Struct.new( :start, :content_block_index, :event_type) SENSITIVE = [] include Aws::Structure end |
#stop_reason ⇒ String
The reason why the model stopped generating output.
920 921 922 923 924 925 926 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 920 class MessageStopEvent < Struct.new( :stop_reason, :additional_model_response_fields, :event_type) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
A tool result that is text.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#tool ⇒ Types::SpecificToolChoice
The Model must request the specified tool.
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1164 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1134 class Tool < Struct.new( :tool_spec, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ToolSpec < Tool; end class Unknown < Tool; end end |
#tool_use ⇒ Types::ToolUseBlockStart
Information about a tool that the model is requesting to use.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#usage ⇒ Types::TokenUsage
Usage information for the conversation stream event.
376 377 378 379 380 381 382 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 376 class ConverseStreamMetadataEvent < Struct.new( :usage, :metrics, :event_type) SENSITIVE = [] include Aws::Structure end |