Class: Aws::BedrockRuntime::Types::ContentBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ContentBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
ContentBlock is a union - when making an API calls you must set exactly one of the members.
ContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ContentBlock corresponding to the set member.
A block of content for a message.
Direct Known Subclasses
Defined Under Namespace
Classes: Image, Text, ToolResult, ToolUse, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image ⇒ Types::ImageBlock
Image to include in the message.
-
#text ⇒ String
Text to include in the message.
-
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
-
#tool_use ⇒ Types::ToolUseBlock
Information about a tool use request from a model.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#image ⇒ Types::ImageBlock
Image to include in the message.
<note markdown=“1”> This field is only supported by Anthropic Claude 3 models.
</note>
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#text ⇒ String
Text to include in the message.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_result ⇒ Types::ToolResultBlock
The result for a tool request that a model makes.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#tool_use ⇒ Types::ToolUseBlock
Information about a tool use request from a model.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 class ContentBlock < Struct.new( :text, :image, :tool_use, :tool_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class Image < ContentBlock; end class ToolUse < ContentBlock; end class ToolResult < ContentBlock; end class Unknown < ContentBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
71 72 73 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 71 def unknown @unknown end |