Class: Aws::BedrockRuntime::Types::ContentBlockDelta

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

ContentBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ContentBlockDelta corresponding to the set member.

A block of content in a streaming response.

Direct Known Subclasses

ReasoningContent, Text, ToolUse, Unknown

Defined Under Namespace

Classes: ReasoningContent, Text, ToolUse, Unknown

Constant Summary collapse

SENSITIVE =
[:reasoning_content]

Instance Attribute Summary collapse

Instance Attribute Details

#reasoning_contentTypes::ReasoningContentBlockDelta

Contains content regarding the reasoning that is carried out by the model. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.



364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 364

class ContentBlockDelta < Struct.new(
  :text,
  :tool_use,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlockDelta; end
  class ToolUse < ContentBlockDelta; end
  class ReasoningContent < ContentBlockDelta; end
  class Unknown < ContentBlockDelta; end
end

#textString

The content text.

Returns:

  • (String)


364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 364

class ContentBlockDelta < Struct.new(
  :text,
  :tool_use,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlockDelta; end
  class ToolUse < ContentBlockDelta; end
  class ReasoningContent < ContentBlockDelta; end
  class Unknown < ContentBlockDelta; end
end

#tool_useTypes::ToolUseBlockDelta

Information about a tool that the model is requesting to use.



364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 364

class ContentBlockDelta < Struct.new(
  :text,
  :tool_use,
  :reasoning_content,
  :unknown)
  SENSITIVE = [:reasoning_content]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ContentBlockDelta; end
  class ToolUse < ContentBlockDelta; end
  class ReasoningContent < ContentBlockDelta; end
  class Unknown < ContentBlockDelta; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



364
365
366
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 364

def unknown
  @unknown
end