Class: Aws::BedrockRuntime::Types::CountTokensInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::CountTokensInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
CountTokensInput is a union - when making an API calls you must set exactly one of the members.
The input value for token counting. The value should be either an
InvokeModel or Converse request body.
Defined Under Namespace
Classes: Converse, InvokeModel, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#converse ⇒ Types::ConverseTokensRequest
A
Converserequest for which to count tokens. -
#invoke_model ⇒ Types::InvokeModelTokensRequest
An
InvokeModelrequest for which to count tokens. -
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#converse ⇒ Types::ConverseTokensRequest
A Converse request for which to count tokens. Use this field when
you want to count tokens for a conversation-based input that would
be sent to the Converse operation.
1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1508 class CountTokensInput < Struct.new( :invoke_model, :converse, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class InvokeModel < CountTokensInput; end class Converse < CountTokensInput; end class Unknown < CountTokensInput; end end |
#invoke_model ⇒ Types::InvokeModelTokensRequest
An InvokeModel request for which to count tokens. Use this field
when you want to count tokens for a raw text input that would be
sent to the InvokeModel operation.
1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1508 class CountTokensInput < Struct.new( :invoke_model, :converse, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class InvokeModel < CountTokensInput; end class Converse < CountTokensInput; end class Unknown < CountTokensInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1508 1509 1510 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1508 def unknown @unknown end |