Class: Aws::BedrockRuntime::Types::CountTokensRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputTypes::CountTokensInput

The input for which to count tokens. The structure of this parameter depends on whether you’re counting tokens for an ‘InvokeModel` or `Converse` request:

  • For ‘InvokeModel` requests, provide the request body in the `invokeModel` field

  • For ‘Converse` requests, provide the messages and system content in the `converse` field

The input format must be compatible with the model specified in the ‘modelId` parameter.



1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1407

class CountTokensRequest < Struct.new(
  :model_id,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#model_idString

The unique identifier or ARN of the foundation model to use for token counting. Each model processes tokens differently, so the token count is specific to the model you specify.

Returns:

  • (String)


1407
1408
1409
1410
1411
1412
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1407

class CountTokensRequest < Struct.new(
  :model_id,
  :input)
  SENSITIVE = []
  include Aws::Structure
end