Class: Aws::BedrockRuntime::Types::DocumentSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::DocumentSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
DocumentSource is a union - when making an API calls you must set exactly one of the members.
Note:
DocumentSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of DocumentSource corresponding to the set member.
Contains the content of a document.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw bytes for the document.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw bytes for the document. If you use an Amazon Web Services SDK, you don’t need to encode the bytes in base64.
991 992 993 994 995 996 997 998 999 1000 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 991 class DocumentSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class Unknown < DocumentSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
991 992 993 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 991 def unknown @unknown end |