Class: Aws::BedrockRuntime::Types::DocumentSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::DocumentSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
DocumentSource is a union - when making an API calls you must set exactly one of the members.
Note:
DocumentSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of DocumentSource corresponding to the set member.
Contains the content of a document.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw bytes for the document.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw bytes for the document. If you use an Amazon Web Services SDK, you don’t need to encode the bytes in base64.
791 792 793 794 795 796 797 798 799 800 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 791 class DocumentSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class Unknown < DocumentSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
791 792 793 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 791 def unknown @unknown end |