Class: Aws::BedrockRuntime::Types::DocumentSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::DocumentSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
DocumentSource is a union - when making an API calls you must set exactly one of the members.
DocumentSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of DocumentSource corresponding to the set member.
Contains the content of the document included in a message when sending a [Converse] or [ConverseStream] request or in the response.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_Converse.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_runtime_ConverseStream.html
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
A base64-encoded string of a UTF-8 encoded file, that is the document to include in the message.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
A base64-encoded string of a UTF-8 encoded file, that is the document to include in the message.
624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 624 class DocumentSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < DocumentSource; end class Unknown < DocumentSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
624 625 626 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 624 def unknown @unknown end |