Class: Aws::BedrockRuntime::Types::GuardrailChecksPromptAttackResultEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::GuardrailChecksPromptAttackResultEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
The evaluation result for a single prompt attack category.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The prompt attack category that was evaluated.
-
#severity_score ⇒ Float
The severity score for the category, ranging from 0.0 to 1.0.
Instance Attribute Details
#category ⇒ String
The prompt attack category that was evaluated.
2497 2498 2499 2500 2501 2502 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2497 class GuardrailChecksPromptAttackResultEntry < Struct.new( :category, :severity_score) SENSITIVE = [] include Aws::Structure end |
#severity_score ⇒ Float
The severity score for the category, ranging from 0.0 to 1.0. Higher values indicate greater severity.
2497 2498 2499 2500 2501 2502 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2497 class GuardrailChecksPromptAttackResultEntry < Struct.new( :category, :severity_score) SENSITIVE = [] include Aws::Structure end |