Class: Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationResultEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationResultEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
The detection result for a single sensitive information entity found in the evaluated messages.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#begin_offset ⇒ Integer
The start character offset of the detected entity within the content block.
-
#confidence_score ⇒ Float
The confidence score for the detection, ranging from 0.0 to 1.0.
-
#content_index ⇒ Integer
The zero-based index of the content block within the message where the entity was detected.
-
#end_offset ⇒ Integer
The end character offset of the detected entity within the content block.
-
#message_index ⇒ Integer
The zero-based index of the message in the input messages array where the entity was detected.
-
#type ⇒ String
The PII entity type that was detected.
Instance Attribute Details
#begin_offset ⇒ Integer
The start character offset of the detected entity within the content block.
2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627 class GuardrailChecksSensitiveInformationResultEntry < Struct.new( :type, :confidence_score, :begin_offset, :end_offset, :message_index, :content_index) SENSITIVE = [] include Aws::Structure end |
#confidence_score ⇒ Float
The confidence score for the detection, ranging from 0.0 to 1.0. Higher values indicate greater confidence.
2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627 class GuardrailChecksSensitiveInformationResultEntry < Struct.new( :type, :confidence_score, :begin_offset, :end_offset, :message_index, :content_index) SENSITIVE = [] include Aws::Structure end |
#content_index ⇒ Integer
The zero-based index of the content block within the message where the entity was detected.
2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627 class GuardrailChecksSensitiveInformationResultEntry < Struct.new( :type, :confidence_score, :begin_offset, :end_offset, :message_index, :content_index) SENSITIVE = [] include Aws::Structure end |
#end_offset ⇒ Integer
The end character offset of the detected entity within the content block.
2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627 class GuardrailChecksSensitiveInformationResultEntry < Struct.new( :type, :confidence_score, :begin_offset, :end_offset, :message_index, :content_index) SENSITIVE = [] include Aws::Structure end |
#message_index ⇒ Integer
The zero-based index of the message in the input messages array where the entity was detected.
2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627 class GuardrailChecksSensitiveInformationResultEntry < Struct.new( :type, :confidence_score, :begin_offset, :end_offset, :message_index, :content_index) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The PII entity type that was detected.
2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2627 class GuardrailChecksSensitiveInformationResultEntry < Struct.new( :type, :confidence_score, :begin_offset, :end_offset, :message_index, :content_index) SENSITIVE = [] include Aws::Structure end |