Class: Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationUsage
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::GuardrailChecksSensitiveInformationUsage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
The text unit usage for the sensitive information check.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text_units ⇒ Integer
The number of text units consumed by the sensitive information check.
Instance Attribute Details
#text_units ⇒ Integer
The number of text units consumed by the sensitive information check.
2647 2648 2649 2650 2651 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2647 class GuardrailChecksSensitiveInformationUsage < Struct.new( :text_units) SENSITIVE = [] include Aws::Structure end |