Class: Aws::BedrockRuntime::Types::GuardrailContentBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

GuardrailContentBlock is a union - when making an API calls you must set exactly one of the members.

The content block to be evaluated by the guardrail.

Direct Known Subclasses

Image, Text, Unknown

Defined Under Namespace

Classes: Image, Text, Unknown

Constant Summary collapse

SENSITIVE =
[:image]

Instance Attribute Summary collapse

Instance Attribute Details

#imageTypes::GuardrailImageBlock

Image within guardrail content block to be evaluated by the guardrail.



2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2722

class GuardrailContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailContentBlock; end
  class Image < GuardrailContentBlock; end
  class Unknown < GuardrailContentBlock; end
end

#textTypes::GuardrailTextBlock

Text within content block to be evaluated by the guardrail.



2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2722

class GuardrailContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailContentBlock; end
  class Image < GuardrailContentBlock; end
  class Unknown < GuardrailContentBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2722
2723
2724
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2722

def unknown
  @unknown
end