Class: Aws::BedrockRuntime::Types::GuardrailContentBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

GuardrailContentBlock is a union - when making an API calls you must set exactly one of the members.

The content block to be evaluated by the guardrail.

Direct Known Subclasses

Image, Text, Unknown

Defined Under Namespace

Classes: Image, Text, Unknown

Constant Summary collapse

SENSITIVE =
[:image]

Instance Attribute Summary collapse

Instance Attribute Details

#imageTypes::GuardrailImageBlock

Image within guardrail content block to be evaluated by the guardrail.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1182

class GuardrailContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailContentBlock; end
  class Image < GuardrailContentBlock; end
  class Unknown < GuardrailContentBlock; end
end

#textTypes::GuardrailTextBlock

Text within content block to be evaluated by the guardrail.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1182

class GuardrailContentBlock < Struct.new(
  :text,
  :image,
  :unknown)
  SENSITIVE = [:image]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailContentBlock; end
  class Image < GuardrailContentBlock; end
  class Unknown < GuardrailContentBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1182
1183
1184
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1182

def unknown
  @unknown
end