Class: Aws::BedrockRuntime::Types::GuardrailContentBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

GuardrailContentBlock is a union - when making an API calls you must set exactly one of the members.

The content block to be evaluated by the guardrail.

Direct Known Subclasses

Text, Unknown

Defined Under Namespace

Classes: Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textTypes::GuardrailTextBlock

Text within content block to be evaluated by the guardrail.



803
804
805
806
807
808
809
810
811
812
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 803

class GuardrailContentBlock < Struct.new(
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < GuardrailContentBlock; end
  class Unknown < GuardrailContentBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



803
804
805
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 803

def unknown
  @unknown
end