Class: Aws::BedrockRuntime::Types::ImageSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ImageSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
ImageSource is a union - when making an API calls you must set exactly one of the members.
Note:
ImageSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ImageSource corresponding to the set member.
The source for an image.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw image bytes for the image.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw image bytes for the image. If you use an AWS SDK, you don’t need to encode the image bytes in base64.
1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1264 class ImageSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageSource; end class Unknown < ImageSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1264 1265 1266 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1264 def unknown @unknown end |