Class: Aws::BedrockRuntime::Types::ImageSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ImageSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
ImageSource is a union - when making an API calls you must set exactly one of the members.
Note:
ImageSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ImageSource corresponding to the set member.
The source for an image.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw image bytes for the image.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw image bytes for the image. If you use an AWS SDK, you don’t need to base64 encode the image bytes.
963 964 965 966 967 968 969 970 971 972 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 963 class ImageSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageSource; end class Unknown < ImageSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
963 964 965 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 963 def unknown @unknown end |