Class: Aws::BedrockRuntime::Types::InvokeGuardrailChecksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::InvokeGuardrailChecksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checks ⇒ Types::GuardrailChecksConfig
The inline check configurations that specify which guardrail checks to run against the messages.
-
#messages ⇒ Array<Types::GuardrailChecksMessage>
The messages to evaluate against the specified guardrail checks.
Instance Attribute Details
#checks ⇒ Types::GuardrailChecksConfig
The inline check configurations that specify which guardrail checks to run against the messages.
3637 3638 3639 3640 3641 3642 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3637 class InvokeGuardrailChecksRequest < Struct.new( :messages, :checks) SENSITIVE = [] include Aws::Structure end |
#messages ⇒ Array<Types::GuardrailChecksMessage>
The messages to evaluate against the specified guardrail checks. Each message includes a role and one or more content blocks.
3637 3638 3639 3640 3641 3642 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3637 class InvokeGuardrailChecksRequest < Struct.new( :messages, :checks) SENSITIVE = [] include Aws::Structure end |