Class: Aws::BedrockRuntime::Types::InvokeModelWithBidirectionalStreamOutput
- Inherits:
-
Enumerator
- Object
- Enumerator
- Aws::BedrockRuntime::Types::InvokeModelWithBidirectionalStreamOutput
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Output from the bidirectional stream that was used for model invocation.
EventStream is an Enumerator of Events.
#event_types #=> Array, returns all modeled event types in the stream
Instance Method Summary collapse
Instance Method Details
#event_types ⇒ Object
5447 5448 5449 5450 5451 5452 5453 5454 5455 5456 5457 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5447 def event_types [ :chunk, :internal_server_exception, :model_stream_error_exception, :validation_exception, :throttling_exception, :model_timeout_exception, :service_unavailable_exception ] end |