Class: Aws::BedrockRuntime::Types::InvokeModelWithResponseStreamResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::InvokeModelWithResponseStreamResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ Types::ResponseStream
Inference response from the model in the format specified by Content-Type.
-
#content_type ⇒ String
The MIME type of the inference result.
Instance Attribute Details
#body ⇒ Types::ResponseStream
Inference response from the model in the format specified by Content-Type. To see the format and content of this field for different models, refer to [Inference parameters].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html
149 150 151 152 153 154 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 149 class InvokeModelWithResponseStreamResponse < Struct.new( :body, :content_type) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
The MIME type of the inference result.
149 150 151 152 153 154 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 149 class InvokeModelWithResponseStreamResponse < Struct.new( :body, :content_type) SENSITIVE = [] include Aws::Structure end |