Class: Aws::BedrockRuntime::Types::OutputConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::OutputConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Output configuration for a model response in a call to Converse or ConverseStream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#effort ⇒ String
The effort level for the model to use when generating a response.
-
#text_format ⇒ Types::OutputFormat
Structured output parameters to control the model's text response.
Instance Attribute Details
#effort ⇒ String
The effort level for the model to use when generating a response.
Higher effort levels allow the model to spend more time reasoning
before responding. Supported values are low, medium, high,
xhigh, and max.
high. Use effort high or below, or enable thinking to use higher
effort levels.
4315 4316 4317 4318 4319 4320 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4315 class OutputConfig < Struct.new( :text_format, :effort) SENSITIVE = [] include Aws::Structure end |
#text_format ⇒ Types::OutputFormat
Structured output parameters to control the model's text response.
4315 4316 4317 4318 4319 4320 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4315 class OutputConfig < Struct.new( :text_format, :effort) SENSITIVE = [] include Aws::Structure end |