Class: Aws::BedrockRuntime::Types::ReasoningContentBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ReasoningContentBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
ReasoningContentBlock is a union - when making an API calls you must set exactly one of the members.
ReasoningContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReasoningContentBlock corresponding to the set member.
Contains content regarding the reasoning that is carried out by the model with respect to the content in the content block. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.
Direct Known Subclasses
Defined Under Namespace
Classes: ReasoningText, RedactedContent, Unknown
Constant Summary collapse
- SENSITIVE =
[:reasoning_text]
Instance Attribute Summary collapse
-
#reasoning_text ⇒ Types::ReasoningTextBlock
The reasoning that the model used to return the output.
-
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#reasoning_text ⇒ Types::ReasoningTextBlock
The reasoning that the model used to return the output.
4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4005 class ReasoningContentBlock < Struct.new( :reasoning_text, :redacted_content, :unknown) SENSITIVE = [:reasoning_text] include Aws::Structure include Aws::Structure::Union class ReasoningText < ReasoningContentBlock; end class RedactedContent < ReasoningContentBlock; end class Unknown < ReasoningContentBlock; end end |
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.
4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4005 class ReasoningContentBlock < Struct.new( :reasoning_text, :redacted_content, :unknown) SENSITIVE = [:reasoning_text] include Aws::Structure include Aws::Structure::Union class ReasoningText < ReasoningContentBlock; end class RedactedContent < ReasoningContentBlock; end class Unknown < ReasoningContentBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4005 4006 4007 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4005 def unknown @unknown end |