Class: Aws::BedrockRuntime::Types::ReasoningContentBlockDelta
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ReasoningContentBlockDelta
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
ReasoningContentBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReasoningContentBlockDelta corresponding to the set member.
Contains content regarding the reasoning that is carried out by the model with respect to the content in the content block. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.
Direct Known Subclasses
Defined Under Namespace
Classes: RedactedContent, Signature, Text, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons.
-
#signature ⇒ String
A token that verifies that the reasoning text was generated by the model.
-
#text ⇒ String
The reasoning that the model used to return the output.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#redacted_content ⇒ String
The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4460 class ReasoningContentBlockDelta < Struct.new( :text, :redacted_content, :signature, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ReasoningContentBlockDelta; end class RedactedContent < ReasoningContentBlockDelta; end class Signature < ReasoningContentBlockDelta; end class Unknown < ReasoningContentBlockDelta; end end |
#signature ⇒ String
A token that verifies that the reasoning text was generated by the model. If you pass a reasoning block back to the API in a multi-turn conversation, include the text and its signature unmodified.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4460 class ReasoningContentBlockDelta < Struct.new( :text, :redacted_content, :signature, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ReasoningContentBlockDelta; end class RedactedContent < ReasoningContentBlockDelta; end class Signature < ReasoningContentBlockDelta; end class Unknown < ReasoningContentBlockDelta; end end |
#text ⇒ String
The reasoning that the model used to return the output.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4460 class ReasoningContentBlockDelta < Struct.new( :text, :redacted_content, :signature, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ReasoningContentBlockDelta; end class RedactedContent < ReasoningContentBlockDelta; end class Signature < ReasoningContentBlockDelta; end class Unknown < ReasoningContentBlockDelta; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4460 4461 4462 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4460 def unknown @unknown end |