Class: Aws::BedrockRuntime::Types::ReasoningContentBlockDelta

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

ReasoningContentBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReasoningContentBlockDelta corresponding to the set member.

Contains content regarding the reasoning that is carried out by the model with respect to the content in the content block. Reasoning refers to a Chain of Thought (CoT) that the model generates to enhance the accuracy of its final response.

Direct Known Subclasses

RedactedContent, Signature, Text, Unknown

Defined Under Namespace

Classes: RedactedContent, Signature, Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#redacted_contentString

The content in the reasoning that was encrypted by the model provider for safety reasons. The encryption doesn’t affect the quality of responses.

Returns:

  • (String)


2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2588

class ReasoningContentBlockDelta < Struct.new(
  :text,
  :redacted_content,
  :signature,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ReasoningContentBlockDelta; end
  class RedactedContent < ReasoningContentBlockDelta; end
  class Signature < ReasoningContentBlockDelta; end
  class Unknown < ReasoningContentBlockDelta; end
end

#signatureString

A token that verifies that the reasoning text was generated by the model. If you pass a reasoning block back to the API in a multi-turn conversation, include the text and its signature unmodified.

Returns:

  • (String)


2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2588

class ReasoningContentBlockDelta < Struct.new(
  :text,
  :redacted_content,
  :signature,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ReasoningContentBlockDelta; end
  class RedactedContent < ReasoningContentBlockDelta; end
  class Signature < ReasoningContentBlockDelta; end
  class Unknown < ReasoningContentBlockDelta; end
end

#textString

The reasoning that the model used to return the output.

Returns:

  • (String)


2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2588

class ReasoningContentBlockDelta < Struct.new(
  :text,
  :redacted_content,
  :signature,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < ReasoningContentBlockDelta; end
  class RedactedContent < ReasoningContentBlockDelta; end
  class Signature < ReasoningContentBlockDelta; end
  class Unknown < ReasoningContentBlockDelta; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2588
2589
2590
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 2588

def unknown
  @unknown
end