Class: Aws::BedrockRuntime::Types::SpecificToolChoice
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::SpecificToolChoice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
The model must request a specific tool. For example, {"tool" : {"name" : "Your tool name"}}. For more information, see Call a tool
with the Converse API in the Amazon Bedrock User Guide
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the tool that the model must request.
Instance Attribute Details
#name ⇒ String
The name of the tool that the model must request.
4683 4684 4685 4686 4687 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4683 class SpecificToolChoice < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |