Class: Aws::BedrockRuntime::Types::SystemContentBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::SystemContentBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
SystemContentBlock is a union - when making an API calls you must set exactly one of the members.
Contains configurations for instructions to provide the model for how to handle input. To learn more, see Using the Converse API.
Defined Under Namespace
Classes: CachePoint, GuardContent, Text, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_point ⇒ Types::CachePointBlock
CachePoint to include in the system prompt.
-
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail.
-
#text ⇒ String
A system prompt for the model.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#cache_point ⇒ Types::CachePointBlock
CachePoint to include in the system prompt.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4769 class SystemContentBlock < Struct.new( :text, :guard_content, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SystemContentBlock; end class GuardContent < SystemContentBlock; end class CachePoint < SystemContentBlock; end class Unknown < SystemContentBlock; end end |
#guard_content ⇒ Types::GuardrailConverseContentBlock
A content block to assess with the guardrail. Use with the Converse or ConverseStream API operations.
For more information, see Use a guardrail with the Converse API in the Amazon Bedrock User Guide.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4769 class SystemContentBlock < Struct.new( :text, :guard_content, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SystemContentBlock; end class GuardContent < SystemContentBlock; end class CachePoint < SystemContentBlock; end class Unknown < SystemContentBlock; end end |
#text ⇒ String
A system prompt for the model.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4769 class SystemContentBlock < Struct.new( :text, :guard_content, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SystemContentBlock; end class GuardContent < SystemContentBlock; end class CachePoint < SystemContentBlock; end class Unknown < SystemContentBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4769 4770 4771 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4769 def unknown @unknown end |