Class: Aws::BedrockRuntime::Types::Tool
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::Tool
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
Tool is a union - when making an API calls you must set exactly one of the members.
Information about a tool that you can use with the Converse API.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#tool_spec ⇒ Types::ToolSpecification
The specfication for the tool.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1134 class Tool < Struct.new( :tool_spec, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ToolSpec < Tool; end class Unknown < Tool; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1134 1135 1136 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1134 def unknown @unknown end |