Class: Aws::BedrockRuntime::Types::ToolConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Configuration information for the tools that you pass to a model.
<note markdown=“1”> This field is only supported by Anthropic Claude 3, Cohere Command R, Cohere Command R+, and Mistral Large models.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tool_choice ⇒ Types::ToolChoice
If supported by model, forces the model to request a tool.
-
#tools ⇒ Array<Types::Tool>
An array of tools that you want to pass to a model.
Instance Attribute Details
#tool_choice ⇒ Types::ToolChoice
If supported by model, forces the model to request a tool.
1196 1197 1198 1199 1200 1201 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1196 class ToolConfiguration < Struct.new( :tools, :tool_choice) SENSITIVE = [] include Aws::Structure end |
#tools ⇒ Array<Types::Tool>
An array of tools that you want to pass to a model.
1196 1197 1198 1199 1200 1201 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 1196 class ToolConfiguration < Struct.new( :tools, :tool_choice) SENSITIVE = [] include Aws::Structure end |