Class: Aws::BedrockRuntime::Types::ToolReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
A reference to a tool in the tool configuration. Used with
ToolAdditionBlock and ToolRemovalBlock to identify which tool to
add or remove mid-conversation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the tool.
-
#server_name ⇒ String
The name of the MCP server that provides the tool.
-
#type ⇒ String
The type of tool reference.
Instance Attribute Details
#name ⇒ String
The name of the tool. Must match the name of a tool declared in the top-level tool configuration.
5084 5085 5086 5087 5088 5089 5090 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5084 class ToolReference < Struct.new( :type, :name, :server_name) SENSITIVE = [] include Aws::Structure end |
#server_name ⇒ String
The name of the MCP server that provides the tool. Required when referencing an MCP tool.
5084 5085 5086 5087 5088 5089 5090 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5084 class ToolReference < Struct.new( :type, :name, :server_name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of tool reference.
5084 5085 5086 5087 5088 5089 5090 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5084 class ToolReference < Struct.new( :type, :name, :server_name) SENSITIVE = [] include Aws::Structure end |