Class: Aws::BedrockRuntime::Types::ToolRemovalBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolRemovalBlock
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
A content block for removing a tool from the available tool set
mid-conversation. Each block references a single tool via its tool
field. Use within a system role message to remove a tool without
re-sending the full tool configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tool ⇒ Types::ToolReference
A reference to the tool to remove from the available tool set.
Instance Attribute Details
#tool ⇒ Types::ToolReference
A reference to the tool to remove from the available tool set.
5103 5104 5105 5106 5107 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 5103 class ToolRemovalBlock < Struct.new( :tool) SENSITIVE = [] include Aws::Structure end |