Class: Aws::BedrockRuntime::Types::ToolResultBlockDelta
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolResultBlockDelta
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
ToolResultBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ToolResultBlockDelta corresponding to the set member.
Contains incremental updates to tool results information during streaming responses. This allows clients to build up tool results data progressively as the response is generated.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#json ⇒ Hash, ...
The JSON schema for the tool result content block.
-
#text ⇒ String
The reasoning the model used to return the output.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#json ⇒ Hash, ...
The JSON schema for the tool result content block. see [JSON Schema Reference].
4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4659 class ToolResultBlockDelta < Struct.new( :text, :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ToolResultBlockDelta; end class Json < ToolResultBlockDelta; end class Unknown < ToolResultBlockDelta; end end |
#text ⇒ String
The reasoning the model used to return the output.
4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4659 class ToolResultBlockDelta < Struct.new( :text, :json, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ToolResultBlockDelta; end class Json < ToolResultBlockDelta; end class Unknown < ToolResultBlockDelta; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4659 4660 4661 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4659 def unknown @unknown end |