Class: Aws::BedrockRuntime::Types::ToolResultBlockDelta
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::ToolResultBlockDelta
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
Note:
ToolResultBlockDelta is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ToolResultBlockDelta corresponding to the set member.
Contains incremental updates to tool results information during streaming responses. This allows clients to build up tool results data progressively as the response is generated.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
The reasoning the model used to return the output.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ String
The reasoning the model used to return the output.
4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4369 class ToolResultBlockDelta < Struct.new( :text, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ToolResultBlockDelta; end class Unknown < ToolResultBlockDelta; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4369 4370 4371 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4369 def unknown @unknown end |