Class: Aws::BedrockRuntime::Types::VideoSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockRuntime::Types::VideoSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockruntime/types.rb
Overview
VideoSource is a union - when making an API calls you must set exactly one of the members.
VideoSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of VideoSource corresponding to the set member.
A video source. You can upload a smaller video as a base64-encoded string as long as the encoded file is less than 25MB. You can also transfer videos up to 1GB in size from an S3 bucket.
Direct Known Subclasses
Defined Under Namespace
Classes: Bytes, S3Location, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
Video content encoded in base64.
-
#s3_location ⇒ Types::S3Location
The location of a video object in an Amazon S3 bucket.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
Video content encoded in base64.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4942 class VideoSource < Struct.new( :bytes, :s3_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < VideoSource; end class S3Location < VideoSource; end class Unknown < VideoSource; end end |
#s3_location ⇒ Types::S3Location
The location of a video object in an Amazon S3 bucket. To see which models support S3 uploads, see [Supported models and features for Converse].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/conversation-inference-supported-models-features.html
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4942 class VideoSource < Struct.new( :bytes, :s3_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < VideoSource; end class S3Location < VideoSource; end class Unknown < VideoSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4942 4943 4944 |
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4942 def unknown @unknown end |