Class: Aws::BedrockRuntime::Types::VideoSource

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

VideoSource is a union - when making an API calls you must set exactly one of the members.

Note:

VideoSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of VideoSource corresponding to the set member.

A video source. You can upload a smaller video as a base64-encoded string as long as the encoded file is less than 25MB. You can also transfer videos up to 1GB in size from an S3 bucket.

Direct Known Subclasses

Bytes, S3Location, Unknown

Defined Under Namespace

Classes: Bytes, S3Location, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bytesString

Video content encoded in base64.

Returns:

  • (String)


3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3688

class VideoSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < VideoSource; end
  class S3Location < VideoSource; end
  class Unknown < VideoSource; end
end

#s3_locationTypes::S3Location

The location of a video object in an Amazon S3 bucket. To see which models support S3 uploads, see [Supported models and features for Converse].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/conversation-inference-supported-models-features.html

Returns:



3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3688

class VideoSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < VideoSource; end
  class S3Location < VideoSource; end
  class Unknown < VideoSource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3688
3689
3690
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3688

def unknown
  @unknown
end