Class: Aws::BedrockRuntime::Types::VideoSource

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Note:

VideoSource is a union - when making an API calls you must set exactly one of the members.

Note:

VideoSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of VideoSource corresponding to the set member.

A video source. You can upload a smaller video as a base64-encoded string as long as the encoded file is less than 25MB. You can also transfer videos up to 1GB in size from an S3 bucket.

Direct Known Subclasses

Bytes, S3Location, Unknown

Defined Under Namespace

Classes: Bytes, S3Location, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bytesString

Video content encoded in base64.

Returns:

  • (String)


3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3223

class VideoSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < VideoSource; end
  class S3Location < VideoSource; end
  class Unknown < VideoSource; end
end

#s3_locationTypes::S3Location

The location of a video object in an S3 bucket.

Returns:



3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3223

class VideoSource < Struct.new(
  :bytes,
  :s3_location,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Bytes < VideoSource; end
  class S3Location < VideoSource; end
  class Unknown < VideoSource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3223
3224
3225
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 3223

def unknown
  @unknown
end