Class: Aws::BedrockRuntime::Types::WebLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockruntime/types.rb

Overview

Provides the URL and domain information for the website that was cited when performing a web search.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domainString

The domain that was cited when performing a web search.

Returns:

  • (String)


4670
4671
4672
4673
4674
4675
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4670

class WebLocation < Struct.new(
  :url,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The URL that was cited when performing a web search.

Returns:

  • (String)


4670
4671
4672
4673
4674
4675
# File 'lib/aws-sdk-bedrockruntime/types.rb', line 4670

class WebLocation < Struct.new(
  :url,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end